@@ -25,10 +25,10 @@ def handle_timer(event):
     )
     fig.shift(-x[0]) # put the whole plot object back at (0,0)
     # pop (remove) the old plot and add the new one
-    plotter.pop().add(fig)
+    plotter.pop().add(fig).render()
 
 
-timer_id = None
+timer_id = -1
 t0 = time.time()
 plotter= Plotter(size=(1200,600))
 button = plotter.add_button(bfunc, states=[" Play ","Pause"], size=40)
