@@ -9,13 +9,13 @@ import numpy as np
 np.random.seed(1)
 
 surf = Grid([0,0,0], res=[25,25])
-ids = np.random.randint(0, surf.N(), 10)  # pick 10 indices
+ids = np.random.randint(0, surf.npoints, 10)  # pick 10 indices
 pts = surf.points()[ids]
 
 ptsource, pttarget = [], []
 for pt in pts:
     pt1 = pt + [0, 0, np.random.randn() * 0.1]
-    pt2 = surf.closestPoint(pt1)
+    pt2 = surf.closest_point(pt1)
     ptsource.append(pt2)
     pttarget.append(pt1)
 
