@@ -2,24 +2,24 @@
 E.g. pink4"""
 from vedo import settings, dataurl, Plotter, Mesh
 
-settings.enableDefaultKeyboardCallbacks = False
+settings.enable_default_keyboard_callbacks = False
 
 def kfunc(evt):
     global msg
-    evt.keyPressed = evt.keyPressed.replace("period", ".")
-    if evt.keyPressed == "BackSpace" and msg:
+    evt.keypress = evt.keypress.replace("period", ".")
+    if evt.keypress == "BackSpace" and msg:
         msg = msg[:-1]
-        evt.keyPressed = ''
-    elif evt.keyPressed == "Return":
+        evt.keypress = ''
+    elif evt.keypress == "Return":
         bfunc()
         return
-    elif evt.keyPressed == "Escape":
+    elif evt.keypress == "Escape":
         plt.close()
 
-    if len(evt.keyPressed) > 1:
+    if len(evt.keypress) > 1:
         return
 
-    msg += f"{evt.keyPressed}"
+    msg += f"{evt.keypress}"
     bu.actor.SetInput(msg)
     plt.render()
 
@@ -32,9 +32,9 @@ plt = Plotter(axes=1)
 plt.interactor.RemoveObservers("CharEvent") # might be needed
 
 msg = ""
-plt.addCallback("key press", kfunc)
+plt.add_callback("key press", kfunc)
 
-bu = plt.addButton(
+bu = plt.add_button(
     bfunc,
     pos=(0.7, 0.05),  # x,y fraction from bottom left corner
     states=["input box"],
