@@ -10,7 +10,7 @@ scals = man.points()[:, 0] + 37  # pick y coords of vertices
 man.cmap("cool", scals).add_scalarbar(title="threshold", horizontal=True)
 
 # make a copy and threshold the mesh
-cutman = man.clone().threshold("PointScalars", 37, 37.5)
+cutman = man.clone().threshold("Scalars", 37, 37.5)
 
 # distribute the meshes on the 2 renderers
 show([(man, __doc__), cutman], N=2, elevation=-30, axes=11).close()
