@@ -12,7 +12,7 @@ for i in range(25):
 def func(evt):
     if not evt.actor:
         return
-    sil = evt.actor.silhouette().lineWidth(6).c('red5')
+    sil = evt.actor.silhouette().linewidth(6).c('red5')
     sil.name = "silu" # give it a name so we can remove the old one
     msg.text("You clicked: "+evt.actor.name)
     plt.remove('silu').add(sil)
@@ -20,6 +20,6 @@ def func(evt):
 msg = Text2D("", pos="bottom-center", c='k', bg='r9', alpha=0.8)
 
 plt = Plotter(axes=1, bg='black')
-plt.addCallback('mouse click', func)
+plt.add_callback('mouse click', func)
 plt.show(spheres, msg, __doc__, zoom=1.2)
 plt.close()
