@@ -5,21 +5,21 @@ then check how many points are inside the surface"""
 #
 from vedo import *
 
-settings.useDepthPeeling = True
+settings.use_depth_peeling = True
 
 pts = Points(np.random.randn(10000, 3)*[3,2,1] + [50,60,70])
 
-elli = pcaEllipsoid(pts, pvalue=0.50)
+elli = pca_ellipsoid(pts, pvalue=0.50)
 
-elli.insidePoints(pts, returnIds=True)
+elli.inside_points(pts, return_ids=True)
 
-ids  = elli.insidePoints(pts, returnIds=True)
+ids  = elli.inside_points(pts, return_ids=True)
 pts.print()  # a new "IsInside" array now exists in pts
 pin = pts.points()[ids]
 print("inside  points #", len(pin))
 
 # Create an inverted mask instead of calling insidePoints(invert=True)
-mask = np.ones(pts.N(), dtype=bool)
+mask = np.ones(pts.npoints, dtype=bool)
 mask[ids] = False
 pout = pts.points()[mask]
 print("outside  points #", len(pout))
