@@ -9,8 +9,9 @@ t1 = Tube(l1, c="green5", r=0.02)
 t2 = Tube(l2, c="blue3",  r=0.02)
 
 r12 = Ribbon(l1, l2, res=(200,5)).alpha(0.5)
-show(r12, t1, t2, __doc__, at=0, N=2, axes=1, viewup="z")
-
 r1  = Ribbon(l1, width=0.1).alpha(0.5).color('orange')
-show(r1, t1, "..or along a single line", at=1, interactive=True).close()
 
+plt = Plotter(N=2, axes=1)
+plt.at(0).show(__doc__, r12, t1, t2)
+plt.at(1).show("..or along a single line", r1, t1, viewup="z")
+plt.interactive().close()
