@@ -1,30 +1,30 @@
 """Use two sliders to change
 color and transparency of a mesh"""
-from vedo import Plotter, dataurl, load
+from vedo import Plotter, Mesh, dataurl
 
 
 def slider1(widget, event):
-    value = widget.GetRepresentation().GetValue()
-    mesh.color(value)
+    mesh.color(widget.value)
 
 def slider2(widget, event):
-    value = widget.GetRepresentation().GetValue()
-    mesh.alpha(value)
+    mesh.alpha(widget.value)
 
 
-plt = Plotter(axes=0)
-mesh = load(dataurl+"magnolia.vtk").flat().lw(0.1)
-plt += mesh
-plt += __doc__
+mesh = Mesh(dataurl+"magnolia.vtk").flat().lw(0.1)
 
-plt.addSlider2D(
-    slider1, -9, 9,
+plt = Plotter()
+plt += [mesh, __doc__]
+
+plt.add_slider(
+    slider1,
+    xmin=-9,
+    xmax=9,
     value=0,
     pos="bottom-right",
     title="color number",
 )
 
-plt.addSlider2D(
+plt.add_slider(
     slider2,
     xmin=0.01,
     xmax=0.99,
