@@ -8,7 +8,7 @@ pts = Points(points).subsample(0.02) # impose a min distance of 2%
 vor = voronoi(pts, padding=0.01)
 vor.cmap('Set3', "VoronoiID", on='cells').wireframe(False)
 
-lab = vor.labels("VoronoiID", cells=True, scale=0.01)
+lab = vor.labels("VoronoiID", on='cells', scale=0.01)
 
 show(pts, vor, lab, __doc__, zoom=1.3).close()
 
