@@ -1,13 +1,4 @@
-"""
-Show fenics mesh and displacement solution.
-
-Refer to original script for the details:
-https://fenicsproject.org/docs/dolfin/2018.1.0/python/
-       demos/hyperelasticity/demo_hyperelasticity.py.html
-"""
-print(__doc__)
-
-########################################################### dolfin
+"""Show fenics mesh and displacement solution."""
 from dolfin import *
 
 # Create mesh and define function space
@@ -24,7 +15,7 @@ r = Expression((
         "scale*0.0",
         "scale*(y0 + (x[1]-y0)*cos(theta) - (x[2]-z0)*sin(theta)-x[1])",
         "scale*(z0 + (x[1]-y0)*sin(theta) + (x[2]-z0)*cos(theta)-x[2])",
-    ), scale=0.5, y0=0.5, z0=0.5, theta=pi/4, degree=2 )
+    ), scale=0.5, y0=0.5, z0=0.5, theta=pi/4, degree=2)
 bcl = DirichletBC(V, c, left)
 bcr = DirichletBC(V, r, right)
 
@@ -36,15 +27,6 @@ solve(inner(grad(w), grad(v)) * dx == inner(c, v) * dx, u, [bcl, bcr])
 
 
 ########################################################### vedo
-from vedo.dolfin import plot, printc, export_window
+from vedo.dolfin import plot
 
-# print out some funny text
-printc("""\idea Try out plot options:
-          \pin color='gold'
-          \pin alpha=0.2, depthpeeling=True
-          \pin mode='mesh warp lines', lw=.05""", c='blue')
-
-plot(u, mode='my displaced mesh please!!', azimuth=45)
-#export_window('ex06_elasticity2.x3d')
-
-printc('\smile Thanks for using vedo!', c='green')
+plot(u, mode='displacements', azimuth=45)
