@@ -11,7 +11,7 @@ embryo.cmap('PRGn', coords[:,1]) # add dummy colors along y
 txt = Text3D(__doc__, font='Bongas', s=350, c='red2', depth=0.05)
 txt.pos(2500, 300, 500)
 
-plt.show(embryo, txt, txt.box(pad=250), axes=1, viewup='z', zoom=1.2)
+plt.show(embryo, txt, txt.box(padding=250), axes=1, viewup='z', zoom=1.2)
 
 # This exports the scene and generates 2 files:
 # embryo.x3d and an example embryo.html to inspect in the browser
