@@ -19,15 +19,15 @@ printc('Mesh cell arrays :', mesh1.celldata.keys())
 gvecs = mesh1.gradient(on='cells')
 cc = mesh1.cell_centers()
 ars = Arrows(cc, cc + gvecs*0.01, c='bone_r').lighting('off')
-ars.add_scalarbar3d(title='|\nablaH|~\dot~0.01 [arb.units]')
+ars.add_scalarbar3d(title='|:nablaH|:dot0.01 [arb.units]')
 
 # colormap the gradient magnitude directly on the mesh
 mesh2 = mesh1.clone(deep=False).lw(0.1).cmap('jet', mag(gvecs), on='cells')
-mesh2.add_scalarbar3d(title='|\nablaH| [arb.units]')
+mesh2.add_scalarbar3d(title='|:nablaH| [arb.units]')
 
 plt = Plotter(N=4, size=(1200,900), axes=11)
 plt.at(0).show(mesh0, isol, __doc__)
 plt.at(1).show(isob)
-plt.at(2).show(mesh1, isol, ars, "Arrows=\nablaH")
-plt.at(3).show(mesh2, "Color=|\nablaH|")
+plt.at(2).show(mesh1, isol, ars, "Arrows=:nablaH")
+plt.at(3).show(mesh2, "Color=|:nablaH|")
 plt.interactive().close()
