@@ -4,22 +4,21 @@ from vedo import Text2D, Plotter
 from vedo.pyplot import plot
 import numpy as np
 
-n = 1000
+n = 500
 x = np.random.randn(n)
 y = np.random.randn(n)
 
-# define what size must have each marker:
+# Define what size must have each marker:
 marker_sizes = np.sin(2*x)/8
 
-# define a (r,g,b) list of colors for each marker:
+# Define a (r,g,b) list of colors for each marker:
 marker_cols = np.c_[np.cos(2*x), np.zeros(n), np.zeros(n)]
 
 
 txt0 = Text2D("A scatter plot of a\n2D gaussian distribution")
 fig0 = plot(
     x, y,
-    lw=0,                      # no joining lines
-    ma=0.3,                    # ma = marker alpha
+    lw=0,                      # no joining of lines
     marker="*",                # marker style
     xtitle="variable A",
     ytitle="variable B",
@@ -29,17 +28,16 @@ fig0 = plot(
 txt1 = Text2D("marker size proportional to sin(2x) ")
 fig1 = plot(
     x, y,
-    ma=0.3,
     lw=0,
     marker="*",
     ms=marker_sizes,           # VARIABLE marker sizes
-    mc='red',                  # same fixed color for markers
+    mc='purple5',              # same fixed color for markers
     grid=False,
 )
 
 txt2 = Text2D("marker size proportional to sin(2x)\nred level   proportional to cos(2x)")
 fig2 = plot(
-    x, y, ma=0.3, lw=0,
+    x, y,  lw=0,
     marker=">",
     ms=marker_sizes,           # VARIABLE marker sizes
     mc=marker_cols,            # VARIABLE marker colors
