@@ -58,14 +58,14 @@ for i in range(0, Nsteps):
 
 # now show the same lines along z representing time
 plt.actors= [] # clean up internal list of objects to show
-plt.camera.Elevation(20)
-plt.camera.Azimuth(20)
+plt.elevation(20)
+plt.azimuth(20)
 bck.alpha(1)
 for i in range(Nsteps):
     p = [0, 0, i*size/Nsteps]  # shift along z
     l, a = lines[i]
     l.cmap("gist_earth_r", a)
     plt.add(box, bck, l.pos(p), barrier.clone().alpha(0.3).pos(p))
-    plt.reset_camera()
+    plt.reset_camera().render()
 
 plt.interactive().close()
