@@ -1,5 +1,5 @@
 """Interactively cut a set of isosurfaces from a volumetric dataset"""
-from vedo import dataurl, show, Volume
+from vedo import dataurl, show, BoxCutter, Volume
 
 # generate an isosurface the volume for each thresholds
 thresholds = [0.1, 0.25, 0.4, 0.6, 0.75, 0.9]
@@ -7,4 +7,11 @@ thresholds = [0.1, 0.25, 0.4, 0.6, 0.75, 0.9]
 # isos is of type Mesh
 isos = Volume(dataurl+'quadric.vti').isosurface(thresholds)
 
-show(isos, __doc__, axes=1, interactive=False).add_cutter_tool(isos)
+plt = show(isos, __doc__, axes=1, interactive=False)
+
+cutter = BoxCutter(isos)
+plt.add(cutter)
+
+plt.interactive()
+plt.close()
+
