@@ -5,8 +5,8 @@ cmap = 'nipy_spectral'
 alpha = np.array([0, 0, 0.05, 0.2, 0.8, 1])
 
 vol = Volume(dataurl+"embryo.slc")
-vol.cmap(cmap).alpha(alpha).addScalarBar3D(c='white')
-xvals = np.linspace(*vol.scalarRange(), len(alpha))
+vol.cmap(cmap).alpha(alpha).add_scalarbar3d(c='white')
+xvals = np.linspace(*vol.scalar_range(), len(alpha))
 
 fig = histogram(vol, logscale=True, c=cmap, ac='white')
 fig+= plot(xvals, alpha*max(fig.frequencies), '--ow', like=fig).z(1)
