@@ -2,7 +2,7 @@
 the associated vector and scalar fields"""
 from vedo import *
 
-settings.useDepthPeeling = True
+settings.use_depth_peeling = True
 
 g = load(dataurl+'structgrid.vts')
 
@@ -15,6 +15,6 @@ print('numpy array shapes are:', coords.shape, vects.shape)
 # build arrows from starting points to endpoints, with colormap
 arrows = Arrows(coords-vects, coords+vects, c='hot_r')
 
-g.cmap('jet', input_array='Density').lineWidth(0.1).alpha(0.3)
+g.cmap('jet', input_array='Density').linewidth(0.1).alpha(0.3)
 
 show(g, arrows, __doc__, axes=7, viewup='z').close()
