@@ -6,13 +6,14 @@ fpath = download(dataurl+"cavity.vtk")
 ugrid = loadUnStructuredGrid(fpath)
 
 # Make a grid of points to probe as type Mesh
-probe = Grid(pos=[0.05,0.08,0.005], normal=[0,1,0], s=[0.1,0.01], res=[20,4], c='k')
+probe = Grid(s=[0.1,0.01], res=[20,4], c='k')
+probe.rotate_x(90).pos(0.05,0.08,0.005)
 
 # Compute stream lines with Runge-Kutta4, return a Mesh
 stream = StreamLines(
     ugrid, probe,
-    activeVectors='U', # name of the active array
-    #tubes={"radius":1e-04, "varyRadius":2},
+    active_vectors='U', # name of the active array
+    #tubes={"radius":1e-04, "vary_radius":2},
     lw=2, # line width
 )
 
