@@ -21,7 +21,10 @@ tets = [[0,1,2,3], [4,5,6,7], [8,9,10,11]]
 scal = [10.0, 20.0, 30.0] # cell scalars
 
 # Create the TeTMesh object
-tm = TetMesh([points,tets]).addCellArray(scal,'myscal').color('jet')
+tm = TetMesh([points,tets])
+tm.celldata["myscal"] = scal
+
+tm.color('jet')
 # tm.color('green') # or set a single color
 
 printc("tetmesh.inputdata():", type(tm.inputdata())) # vtkUnstructuredGrid
