@@ -15,15 +15,15 @@ seeds = surf.clone().subsample(f2).ps(10).c("black")
 
 # assign to each tetrahedron the id of the closest seed point
 cids = []
-for p in tmesh.cellCenters():
-    cid = seeds.closestPoint(p, returnPointId=True)
+for p in tmesh.cell_centers():
+    cid = seeds.closest_point(p, return_point_id=True)
     cids.append(cid)
 tmesh.celldata["fragment"] = cids
 # tmesh.celldata.select("fragment")# bug, has no effect, needs name=...
 
 pieces = []
-for i in range(seeds.NPoints()):
-    tc = tmesh.clone().threshold(name="fragment", above=i - 0.1, below=i + 0.1)
+for i in range(seeds.npoints):
+    tc = tmesh.clone().threshold(name="fragment", above=i-0.1, below=i+0.1)
     mc = tc.tomesh(fill=False).color(i)
     pieces.append(mc)
 
@@ -32,8 +32,8 @@ plt = Plotter(size=(1200, 800), axes=1)
 plt.show(txt, pieces)
 for i in range(20):
     for pc in pieces:
-        cm = pc.centerOfMass()
+        cm = pc.center_of_mass()
         pc.shift(cm / 25)
-    txt.text(f"{__doc__}\n\nNr. of pieces = {seeds.N()}")
+    txt.text(f"{__doc__}\n\nNr. of pieces = {seeds.npoints}")
     plt.render()
 plt.interactive().close()
