@@ -28,7 +28,7 @@ from vedo.colors import *
 from vedo.utils import *
 from vedo.base import *
 from vedo.shapes import *
-from vedo.io import *
+from vedo.file_io import *
 from vedo.ugrid import *
 from vedo.assembly import *
 from vedo.pointcloud import *
@@ -40,6 +40,7 @@ from vedo.addons import *
 from vedo.plotter import *
 
 from vedo import applications
+from vedo import interactor_modes
 
 try:
     import platform
@@ -89,7 +90,7 @@ last_figure = None
 ######################################################################### LOGGING
 class _LoggingCustomFormatter(logging.Formatter):
 
-    logformat = "[vedo.%(filename)s:%(lineno)d] %(levelname)s: %(message)s"
+    logformat = "[vedo.%(filename)s] %(levelname)s: %(message)s"
 
     white = "\x1b[1m"
     grey = "\x1b[2m\x1b[1m\x1b[38;20m"
@@ -109,7 +110,7 @@ class _LoggingCustomFormatter(logging.Formatter):
     def format(self, record):
         log_fmt = self.FORMATS.get(record.levelno)
         formatter = logging.Formatter(log_fmt)
-        return formatter.format(record)
+        return formatter.format(record).replace(".py", "")
 
 logger = logging.getLogger("vedo")
 
