@@ -112,7 +112,7 @@ class _DataArrayHelper:
                     raise e
 
             data.AddArray(varr)
-            return ############
+            return  ############
 
         else:
             raise RuntimeError()
@@ -142,7 +142,7 @@ class _DataArrayHelper:
             data = self.actor.inputdata().GetPointData()
         elif self.association == 1:
             data = self.actor.inputdata().GetCellData()
-        elif  self.association == 2:
+        elif self.association == 2:
             data = self.actor.inputdata().GetFieldData()
         arrnames = []
         for i in range(data.GetNumberOfArrays()):
@@ -157,9 +157,21 @@ class _DataArrayHelper:
             self.actor.inputdata().GetPointData().RemoveArray(key)
         elif self.association == 1:
             self.actor.inputdata().GetCellData().RemoveArray(key)
-        elif  self.association == 2:
+        elif self.association == 2:
             self.actor.inputdata().GetFieldData().RemoveArray(key)
 
+    def clear(self):
+        """Remove all data associated to this object"""
+        if self.association == 0:
+            data = self.actor.inputdata().GetPointData()
+        elif self.association == 1:
+            data = self.actor.inputdata().GetCellData()
+        elif self.association == 2:
+            data = self.actor.inputdata().GetFieldData()
+        for i in range(data.GetNumberOfArrays()):
+            name = data.GetArray(i).GetName()
+            data.RemoveArray(name)
+
     def rename(self, oldname, newname):
         """Rename an array"""
         if self.association == 0:
@@ -171,9 +183,7 @@ class _DataArrayHelper:
         if varr:
             varr.SetName(newname)
         else:
-            vedo.logger.warning(
-                f"Cannot rename non existing array {oldname} to {newname}"
-            )
+            vedo.logger.warning(f"Cannot rename non existing array {oldname} to {newname}")
 
     def select(self, key):
         """Select one specific array by its name to make it the `active` one."""
@@ -186,26 +196,133 @@ class _DataArrayHelper:
 
         if isinstance(key, int):
             key = data.GetArrayName(key)
+
+        arr = data.GetArray(key)
+        if not arr:
+            return
+
+        nc = arr.GetNumberOfComponents()
+        if nc == 1:
+            data.SetActiveScalars(key)
+        elif nc >= 2:
+            if "rgb" in key.lower():
+                data.SetActiveScalars(key)
+                # try:
+                #     self.actor.mapper().SetColorModeToDirectScalars()
+                # except AttributeError:
+                #     pass
+            else:
+                data.SetActiveVectors(key)
+        elif nc >= 4:
+            data.SetActiveTensors(key)
+
+        try:
+            self.actor.mapper().SetArrayName(key)
+            self.actor.mapper().ScalarVisibilityOn()
+            # .. could be a volume mapper
+        except AttributeError:
+            pass
+
+    def select_scalars(self, key):
+        """Select one specific scalar array by its name to make it the `active` one."""
+        if self.association == 0:
+            data = self.actor.inputdata().GetPointData()
+            self.actor.mapper().SetScalarModeToUsePointData()
+        else:
+            data = self.actor.inputdata().GetCellData()
+            self.actor.mapper().SetScalarModeToUseCellData()
+
+        if isinstance(key, int):
+            key = data.GetArrayName(key)
+
         data.SetActiveScalars(key)
 
-        if hasattr(self.actor.mapper(), "SetArrayName"):
+        try:
             self.actor.mapper().SetArrayName(key)
-
-        if hasattr(self.actor.mapper(), "ScalarVisibilityOn"):  # could be volume mapper
             self.actor.mapper().ScalarVisibilityOn()
+        except AttributeError:
+            pass
+
+    def select_vectors(self, key):
+        """Select one specific vector array by its name to make it the `active` one."""
+        if self.association == 0:
+            data = self.actor.inputdata().GetPointData()
+            self.actor.mapper().SetScalarModeToUsePointData()
+        else:
+            data = self.actor.inputdata().GetCellData()
+            self.actor.mapper().SetScalarModeToUseCellData()
+
+        if isinstance(key, int):
+            key = data.GetArrayName(key)
+
+        data.SetActiveVectors(key)
+
+        try:
+            self.actor.mapper().SetArrayName(key)
+            self.actor.mapper().ScalarVisibilityOn()
+        except AttributeError:
+            pass
 
     def print(self, **kwargs):
         """Print the array names available to terminal"""
         colors.printc(self.keys(), **kwargs)
 
+    def __repr__(self) -> str:
+        """Representation"""
+
+        def _get_str(pd, header):
+            if pd.GetNumberOfArrays():
+                out = f"\x1b[2m\x1b[1m\x1b[7m{header}"
+                if self.actor.name:
+                    out += f" in {self.actor.name}"
+                out += f" contains {pd.GetNumberOfArrays()} array(s)\x1b[0m"
+                for i in range(pd.GetNumberOfArrays()):
+                    varr = pd.GetArray(i)
+                    out += f"\n\x1b[1m\x1b[4mArray name    : {varr.GetName()}\x1b[0m"
+                    out += "\nindex".ljust(15) + f": {i}"
+                    t = varr.GetDataType()
+                    if t in vedo.utils.array_types:
+                        out += f"\ntype".ljust(15)
+                        out += f": {vedo.utils.array_types[t][1]} ({vedo.utils.array_types[t][0]})"
+                    shape = (varr.GetNumberOfTuples(), varr.GetNumberOfComponents())
+                    out += "\nshape".ljust(15) + f": {shape}"
+                    out += "\nrange".ljust(15) + f": {np.array(varr.GetRange())}"
+                    out += "\nmax id".ljust(15) + f": {varr.GetMaxId()}"
+                    out += "\nlook up table".ljust(15) + f": {bool(varr.GetLookupTable())}"
+                    out += "\nin-memory size".ljust(15) + f": {varr.GetActualMemorySize()} KB"
+            else:
+                out += " has no associated data."
+            return out
+
+        if self.association == 0:
+            out = _get_str(self.actor._data.GetPointData(), "Point Data")
+        elif self.association == 1:
+            out = _get_str(self.actor._data.GetCellData(), "Cell Data")
+        elif self.association == 2:
+            pd = self.actor._data.GetFieldData()
+            if pd.GetNumberOfArrays():
+                out = f"\x1b[2m\x1b[1m\x1b[7mMeta Data"
+                if self.actor.name:
+                    out += f" in {self.actor.name}"
+                out += f" contains {pd.GetNumberOfArrays()} entries\x1b[0m"
+                for i in range(pd.GetNumberOfArrays()):
+                    varr = pd.GetAbstractArray(i)
+                    out += f"\n\x1b[1m\x1b[4mEntry name    : {varr.GetName()}\x1b[0m"
+                    out += "\nindex".ljust(15) + f": {i}"
+                    shape = (varr.GetNumberOfTuples(), varr.GetNumberOfComponents())
+                    out += "\nshape".ljust(15) + f": {shape}"
+
+        return out
+
 
 ###############################################################################
 class Base3DProp:
     """
     Base class to manage positioning and size of the objects in space and other properties.
 
-    .. warning:: Do not use this class to instanciate objects
+    .. warning:: Do not use this class to instantiate objects
     """
+
     def __init__(self):
         """
         Base class to manage positioning and size of the objects in space and other properties.
@@ -237,7 +354,6 @@ class Base3DProp:
         # self.scalarbars = dict() #TODO
         self.pipeline = None
 
-
     def address(self):
         """
         Return a unique memory address integer which may serve as the ID of the
@@ -417,10 +533,12 @@ class Base3DProp:
     def rotateX(self, *a, **b):
         """Deprecated. Please use `rotate_x()`."""
         return self.rotate_x(*a, **b)
+
     @deprecated(reason=vedo.colors.red + "Please use rotate_y()" + vedo.colors.reset)
     def rotateY(self, *a, **b):
         """Deprecated. Please use `rotate_y()`."""
         return self.rotate_y(*a, **b)
+
     @deprecated(reason=vedo.colors.red + "Please use rotate_z()" + vedo.colors.reset)
     def rotateZ(self, *a, **b):
         """Deprecated. Please use `rotate_z()`."""
@@ -458,7 +576,7 @@ class Base3DProp:
             rotation : (float)
                 rotate object around newaxis.
             concatenate : (bool)
-                concatenate the orietation operation with the previous existing transform (if any)
+                concatenate the orientation operation with the previous existing transform (if any)
             xyplane : (bool)
                 make an extra rotation to keep the object aligned to the xy-plane
             rad : (bool)
@@ -511,7 +629,7 @@ class Base3DProp:
             T.RotateWXYZ(rotation, initaxis)
         if xyplane:
             angleph = np.arctan2(newaxis[1], newaxis[0])
-            T.RotateWXYZ(np.rad2deg(angleph + angleth), initaxis) # compensation
+            T.RotateWXYZ(np.rad2deg(angleph + angleth), initaxis)  # compensation
         T.RotateWXYZ(np.rad2deg(angleth), crossvec)
         T.Translate(p)
 
@@ -535,7 +653,6 @@ class Base3DProp:
         # self.SetUserTransform(T)
         # self.transform = T
 
-
     def scale(self, s=None, reset=False):
         """
         Set/get object's scaling factor.
@@ -604,11 +721,10 @@ class Base3DProp:
             tr = tr.GetInverse()
         return tr
 
-
     @deprecated(reason=vedo.colors.red + "Please use apply_transform()" + vedo.colors.reset)
     def applyTransform(self, T, reset=False, concatenate=False):
         """Deprecated. Please use `apply_transform()`"""
-        return self.apply_transform(T,reset,concatenate)
+        return self.apply_transform(T, reset, concatenate)
 
     def apply_transform(self, T, reset=False, concatenate=False):
         """
@@ -702,7 +818,7 @@ class Base3DProp:
             for sh in self.shadows:
                 sh.VisibilityOn()
         except AttributeError:
-            pass        
+            pass
         return self
 
     def off(self):
@@ -720,9 +836,9 @@ class Base3DProp:
             for sh in self.shadows:
                 sh.VisibilityOff()
         except AttributeError:
-            pass        
+            pass
         return self
-    
+
     def toggle(self):
         """Toggle object visibility on/off."""
         v = self.GetVisibility()
@@ -754,7 +870,7 @@ class Base3DProp:
         bx = vedo.shapes.Box(
             pos,
             length * scale + padding[0],
-            width  * scale + padding[1],
+            width * scale + padding[1],
             height * scale + padding[2],
             c="gray",
         )
@@ -785,7 +901,7 @@ class Base3DProp:
             pts = self.points()
             xmin, ymin, zmin = np.min(pts, axis=0)
             xmax, ymax, zmax = np.max(pts, axis=0)
-            return [xmin,xmax, ymin,ymax, zmin,zmax]
+            return [xmin, xmax, ymin, ymax, zmin, zmax]
         except (AttributeError, ValueError):
             return self.GetBounds()
 
@@ -808,8 +924,10 @@ class Base3DProp:
     def zbounds(self, i=None):
         """Get the bounds `[zmin,zmax]`. Can specify upper or lower with i (0,1)."""
         b = self.bounds()
-        if i == 0: return b[4]
-        if i == 1: return b[5]
+        if i == 0:
+            return b[4]
+        if i == 1:
+            return b[5]
         return (b[4], b[5])
 
     @deprecated(reason=vedo.colors.red + "Please use diagonal_size()" + vedo.colors.reset)
@@ -826,12 +944,12 @@ class Base3DProp:
 
     def copy_data_from(self, obj):
         """Copy all data (point and cell data) from this input object"""
-        self._data.GetPointData().PassData(obj._data.GetPointData())
-        self._data.GetCellData().PassData(obj._data.GetCellData())
+        self.inputdata().GetPointData().PassData(obj.inputdata().GetPointData())
+        self.inputdata().GetCellData().PassData(obj.inputdata().GetCellData())
         self.pipeline = utils.OperationNode(
-            f"copy_data_from\n{obj.__class__.__name__}", 
+            f"copy_data_from\n{obj.__class__.__name__}",
             parents=[self, obj],
-            shape='note',
+            shape="note",
             c="#ccc5b9",
         )
         return self
@@ -853,15 +971,7 @@ class Base3DProp:
         """
         return vedo.plotter.show(self, **options)
 
-    def thumbnail(
-            self, 
-            zoom=1.25,
-            size=(200, 200),
-            bg="white", 
-            azimuth=0, 
-            elevation=0, 
-            axes=False,
-        ):
+    def thumbnail(self, zoom=1.25, size=(200, 200), bg="white", azimuth=0, elevation=0, axes=False):
         """Build a thumbnail of the object and return it as an array."""
         # speed is about 20Hz for size=[200,200]
         ren = vtk.vtkRenderer()
@@ -884,7 +994,7 @@ class Base3DProp:
 
         nx, ny = ren_win.GetSize()
         arr = vtk.vtkUnsignedCharArray()
-        ren_win.GetRGBACharPixelData(0, 0, nx-1, ny-1, 0, arr)
+        ren_win.GetRGBACharPixelData(0, 0, nx - 1, ny - 1, 0, arr)
         narr = utils.vtk2numpy(arr).T[:3].T.reshape([ny, nx, 3])
         narr = np.ascontiguousarray(np.flip(narr, axis=0))
 
@@ -901,8 +1011,9 @@ class BaseActor2D(vtk.vtkActor2D):
     """
     Base class.
 
-    .. warning:: Do not use this class to instanciate objects.
+    .. warning:: Do not use this class to instantiate objects.
     """
+
     def __init__(self):
         """Manage 2D objects."""
         super().__init__()
@@ -920,12 +1031,12 @@ class BaseActor2D(vtk.vtkActor2D):
     def pos(self, px=None, py=None):
         """Set/Get the screen-coordinate position."""
         if isinstance(px, str):
-            vedo.logger.error("Use string descriptors only inside the contructor")
+            vedo.logger.error("Use string descriptors only inside the constructor")
             return self
         if px is None:
             return np.array(self.GetPosition(), dtype=int)
-        if  py is not None:
-            p = [px,py]
+        if py is not None:
+            p = [px, py]
         else:
             p = px
         assert len(p) == 2, "Error: len(pos) must be 2 for BaseActor2D"
@@ -935,7 +1046,7 @@ class BaseActor2D(vtk.vtkActor2D):
     def coordinate_system(self, value=None):
         """
         Set/get the coordinate system which this coordinate is defined in.
-        
+
         The options are:
             0. Display
             1. Normalized Display
@@ -963,7 +1074,7 @@ class BaseActor2D(vtk.vtkActor2D):
 
     def toggle(self):
         """Toggle object visibility."""
-        self.SetVisibility(not(self.GetVisibility()))
+        self.SetVisibility(not self.GetVisibility())
         return self
 
     def pickable(self, value=True):
@@ -982,9 +1093,9 @@ class BaseActor2D(vtk.vtkActor2D):
             return self.GetProperty().GetPointSize()
         self.GetProperty().SetPointSize(point_size)
         return self
-    
+
     def ontop(self, value=True):
-        """Keep the object always on top of everithing else."""
+        """Keep the object always on top of everything else."""
         if value:
             self.GetProperty().SetDisplayLocationToForeground()
         else:
@@ -997,21 +1108,21 @@ class BaseActor(Base3DProp):
     """
     Base class.
 
-    .. warning:: Do not use this class to instanciate objects, use one the above instead.
+    .. warning:: Do not use this class to instantiate objects, use one the above instead.
     """
+
     def __init__(self):
         """
         Base class to add operative and data
         functionality to `Mesh`, `Assembly`, `Volume` and `Picture` objects.
         """
-        
+
         super().__init__()
 
         self._mapper = None
         self._caption = None
         self.property = None
 
-
     def mapper(self, new_mapper=None):
         """Return the `vtkMapper` data object, or update it with a new one."""
         if new_mapper:
@@ -1064,7 +1175,6 @@ class BaseActor(Base3DProp):
         """Retrieve the number of cells."""
         return self.inputdata().GetNumberOfCells()
 
-
     def points(self, pts=None, transformed=True):
         """
         Set/Get the vertex coordinates of a mesh or point cloud.
@@ -1140,13 +1250,15 @@ class BaseActor(Base3DProp):
         data.Modified()
         self._mapper.Modified()
         self.pipeline = utils.OperationNode(
-            "delete_cells", parents=[self],
-            comment=f"#cells {self._data.GetNumberOfCells()}",
+            "delete_cells", parents=[self], comment=f"#cells {self._data.GetNumberOfCells()}"
         )
         return self
 
     def mark_boundaries(self):
-        """Mark cells and vertices of the mesh if they lie on a boundary."""
+        """
+        Mark cells and vertices of the mesh if they lie on a boundary.
+        A new array called `BoundaryCells` is added to the mesh.
+        """
         mb = vtk.vtkMarkBoundaryFilter()
         mb.SetInputData(self._data)
         mb.Update()
@@ -1263,9 +1375,7 @@ class BaseActor(Base3DProp):
             elif style=='default' : pars = [0.1, 1.0, 0.05, 5, c]
             else:
                 vedo.logger.error("in lighting(): Available styles are")
-                vedo.logger.error(
-                    "[default, metallic, plastic, shiny, glossy, ambient, off]"
-                )
+                vedo.logger.error("[default, metallic, plastic, shiny, glossy, ambient, off]")
                 raise RuntimeError()
             pr.SetAmbient(pars[0])
             pr.SetDiffuse(pars[1])
@@ -1390,16 +1500,15 @@ class BaseActor(Base3DProp):
         """
         return _DataArrayHelper(self, 2)
 
-
     def map_cells_to_points(self, arrays=(), move=False):
         """
         Interpolate cell data (i.e., data specified per cell or face)
         into point data (i.e., data specified at each vertex).
         The method of transformation is based on averaging the data values
         of all cells using a particular point.
-        
+
         A custom list of arrays to be mapped can be passed in input.
- 
+
         Set `move=True` to delete the original `celldata` array.
         """
         c2p = vtk.vtkCellDataToPointData()
@@ -1479,7 +1588,7 @@ class BaseActor(Base3DProp):
         rs = vtk.vtkResampleWithDataSet()
         rs.SetInputData(self.inputdata())
         rs.SetSourceData(source.inputdata())
-        
+
         rs.SetPassPointArrays(True)
         rs.SetPassCellArrays(True)
         rs.SetPassFieldArrays(True)
@@ -1492,8 +1601,8 @@ class BaseActor(Base3DProp):
         rs.Update()
         self._update(rs.GetOutput())
         self.pipeline = utils.OperationNode(
-            f"resample_data_from\n{source.__class__.__name__}",
-            parents=[self, source])
+            f"resample_data_from\n{source.__class__.__name__}", parents=[self, source]
+        )
         return self
 
     def add_ids(self):
@@ -1595,10 +1704,10 @@ class BaseActor(Base3DProp):
         div.SetDivergenceArrayName("Divergence")
         div.SetFasterApproximation(fast)
         div.Update()
-        if on.startswith('p'):
-            dvecs = utils.vtk2numpy(div.GetOutput().GetPointData().GetArray('Divergence'))
+        if on.startswith("p"):
+            dvecs = utils.vtk2numpy(div.GetOutput().GetPointData().GetArray("Divergence"))
         else:
-            dvecs = utils.vtk2numpy(div.GetOutput().GetCellData().GetArray('Divergence'))
+            dvecs = utils.vtk2numpy(div.GetOutput().GetCellData().GetArray("Divergence"))
         return dvecs
 
     def vorticity(self, array_name=None, on="points", fast=False):
@@ -1638,31 +1747,30 @@ class BaseActor(Base3DProp):
         vort.SetVorticityArrayName("Vorticity")
         vort.SetFasterApproximation(fast)
         vort.Update()
-        if on.startswith('p'):
-            vvecs = utils.vtk2numpy(vort.GetOutput().GetPointData().GetArray('Vorticity'))
+        if on.startswith("p"):
+            vvecs = utils.vtk2numpy(vort.GetOutput().GetPointData().GetArray("Vorticity"))
         else:
-            vvecs = utils.vtk2numpy(vort.GetOutput().GetCellData().GetArray('Vorticity'))
+            vvecs = utils.vtk2numpy(vort.GetOutput().GetCellData().GetArray("Vorticity"))
         return vvecs
 
-
     @deprecated(reason=vedo.colors.red + "Please use method add_scalarbar()" + vedo.colors.reset)
     def addScalarBar(self, *a, **b):
         """Deprecated. Please use method `add_scalarbar()`"""
         return self.add_scalarbar(*a, **b)
 
     def add_scalarbar(
-            self,
-            title="",
-            pos=(0.8,0.05),
-            title_yoffset=15,
-            font_size=12,
-            size=(None,None),
-            nlabels=None,
-            c=None,
-            horizontal=False,
-            use_alpha=True,
-            label_format=':6.3g',
-        ):
+        self,
+        title="",
+        pos=(0.8, 0.05),
+        title_yoffset=15,
+        font_size=12,
+        size=(None, None),
+        nlabels=None,
+        c=None,
+        horizontal=False,
+        use_alpha=True,
+        label_format=":6.3g",
+    ):
         """
         Add a 2D scalar bar for the specified obj.
 
@@ -1709,7 +1817,7 @@ class BaseActor(Base3DProp):
         self,
         title="",
         pos=None,
-        s=(None, None),
+        size=(None, None),
         title_font="",
         title_xoffset=-1.5,
         title_yoffset=0.0,
@@ -1734,7 +1842,7 @@ class BaseActor(Base3DProp):
         The new scalarbar object (Assembly) will be accessible as obj.scalarbar
 
         Arguments:
-            s : (list)
+            size : (list)
                 (thickness, length) of scalarbar
             title : (str)
                 scalar bar title
@@ -1780,7 +1888,7 @@ class BaseActor(Base3DProp):
             self,
             title,
             pos,
-            s,
+            size,
             title_font,
             title_xoffset,
             title_yoffset,
@@ -1805,12 +1913,9 @@ class BaseActor(Base3DProp):
     ###################################################################################
     def write(self, filename, binary=True):
         """Write object to file."""
-        out = vedo.io.write(self, filename, binary)
+        out = vedo.file_io.write(self, filename, binary)
         out.pipeline = utils.OperationNode(
-            "write", parents=[self],
-            comment=filename[:15],
-            shape="folder",
-            c="#8a817c",
+            "write", parents=[self], comment=filename[:15], shape="folder", c="#8a817c"
         )
         return out
 
@@ -1820,8 +1925,9 @@ class BaseGrid(BaseActor):
     """
     Base class for grid datasets.
 
-    .. warning:: Do not use this class to instanciate objects.
+    .. warning:: Do not use this class to instantiate objects.
     """
+
     def __init__(self):
         """Base class for grid datasets."""
 
@@ -1830,7 +1936,7 @@ class BaseGrid(BaseActor):
         self._data = None
         self.useCells = True
         self._color = None
-        self._alpha = [0,1]
+        self._alpha = [0, 1]
 
         # -----------------------------------------------------------
 
@@ -1882,11 +1988,9 @@ class BaseGrid(BaseActor):
             msh.mapper().SetScalarModeToUseCellData()
         else:
             msh.mapper().SetScalarModeToUsePointData()
-        
+
         msh.pipeline = utils.OperationNode(
-            "tomesh", parents=[self], 
-            comment=f"fill={fill}",
-            c="#9e2a2b:#e9c46a",
+            "tomesh", parents=[self], comment=f"fill={fill}", c="#9e2a2b:#e9c46a"
         )
         return msh
 
@@ -1938,6 +2042,10 @@ class BaseGrid(BaseActor):
                 force the max of the scalar range to be this value
         """
         # supersedes method in Points, Mesh
+
+        if col is None:
+            return self
+        
         if vmin is None:
             vmin, _ = self._data.GetScalarRange()
         if vmax is None:
@@ -2007,7 +2115,7 @@ class BaseGrid(BaseActor):
 
         if utils.is_sequence(alpha):
             alpha = np.array(alpha)
-            if len(alpha.shape)==1: # user passing a flat list e.g. (0.0, 0.3, 0.9, 1)
+            if len(alpha.shape) == 1:  # user passing a flat list e.g. (0.0, 0.3, 0.9, 1)
                 for i, al in enumerate(alpha):
                     xalpha = vmin + (vmax - vmin) * i / (len(alpha) - 1)
                     # Create transfer mapping scalar value to opacity
@@ -2045,7 +2153,7 @@ class BaseGrid(BaseActor):
     def shrink(self, fraction=0.8):
         """
         Shrink the individual cells to improve visibility.
-        
+
         ![](https://vedo.embl.es/images/feats/shrink_hex.png)
         """
         sf = vtk.vtkShrinkFilter()
@@ -2054,7 +2162,8 @@ class BaseGrid(BaseActor):
         sf.Update()
         self._update(sf.GetOutput())
         self.pipeline = utils.OperationNode(
-            "shrink", comment=f"by {fraction}", parents=[self], c='#9e2a2b')
+            "shrink", comment=f"by {fraction}", parents=[self], c="#9e2a2b"
+        )
         return self
 
     def isosurface(self, value=None, flying_edges=True):
@@ -2098,16 +2207,15 @@ class BaseGrid(BaseActor):
         out.mapper().SetScalarRange(scrange[0], scrange[1])
 
         out.pipeline = utils.OperationNode(
-            "isosurface", parents=[self], 
-            comment=f"#pts {out._data.GetNumberOfPoints()}",
+            "isosurface",
+            parents=[self],
+            comment=f"#pts {out.inputdata().GetNumberOfPoints()}",
             c="#4cc9f0:#e9c46a",
         )
         return out
 
     def legosurface(
-        self, vmin=None, vmax=None, 
-        invert=False, boundary=False,
-        array_name='input_scalars',
+        self, vmin=None, vmax=None, invert=False, boundary=False, array_name="input_scalars"
     ):
         """
         Represent an object - typically a `Volume` - as lego blocks (voxels).
@@ -2160,9 +2268,7 @@ class BaseGrid(BaseActor):
         m.celldata.select(array_name)
 
         m.pipeline = utils.OperationNode(
-            "legosurface", parents=[self], 
-            comment=f"array: {array_name}",
-            c="#4cc9f0:#e9c46a",
+            "legosurface", parents=[self], comment=f"array: {array_name}", c="#4cc9f0:#e9c46a"
         )
         return m
 
@@ -2200,8 +2306,7 @@ class BaseGrid(BaseActor):
         clipper.Update()
         cout = clipper.GetOutput()
         self._update(cout)
-        self.pipeline = utils.OperationNode(
-            "cut_with_plane", parents=[self], c='#9e2a2b')
+        self.pipeline = utils.OperationNode("cut_with_plane", parents=[self], c="#9e2a2b")
         return self
 
     def cut_with_box(self, box):
@@ -2230,8 +2335,7 @@ class BaseGrid(BaseActor):
         bc.SetBoxClip(*boxb)
         bc.Update()
         self._update(bc.GetOutput())
-        self.pipeline = utils.OperationNode(
-            "cut_with_box", parents=[self, box], c='#9e2a2b')
+        self.pipeline = utils.OperationNode("cut_with_box", parents=[self, box], c="#9e2a2b")
         return self
 
     def cut_with_mesh(self, mesh, invert=False, whole_cells=False, only_boundary=False):
@@ -2282,8 +2386,7 @@ class BaseGrid(BaseActor):
                     self.pointdata.select(scalname)
 
         self._update(cug)
-        self.pipeline = utils.OperationNode(
-            "cut_with_mesh", parents=[self, mesh], c='#9e2a2b')
+        self.pipeline = utils.OperationNode("cut_with_mesh", parents=[self, mesh], c="#9e2a2b")
         return self
 
     def extract_cells_on_plane(self, origin, normal):
@@ -2304,8 +2407,10 @@ class BaseGrid(BaseActor):
 
         self._update(bf.GetOutput())
         self.pipeline = utils.OperationNode(
-            "extract_cells_on_plane", parents=[self],
-            comment=f"#cells {self._data.GetNumberOfCells()}", c='#9e2a2b',
+            "extract_cells_on_plane",
+            parents=[self],
+            comment=f"#cells {self._data.GetNumberOfCells()}",
+            c="#9e2a2b",
         )
         return self
 
@@ -2327,8 +2432,10 @@ class BaseGrid(BaseActor):
 
         self._update(bf.GetOutput())
         self.pipeline = utils.OperationNode(
-            "extract_cells_on_sphere", parents=[self],
-            comment=f"#cells {self._data.GetNumberOfCells()}", c='#9e2a2b',
+            "extract_cells_on_sphere",
+            parents=[self],
+            comment=f"#cells {self._data.GetNumberOfCells()}",
+            c="#9e2a2b",
         )
         return self
 
@@ -2350,8 +2457,10 @@ class BaseGrid(BaseActor):
         bf.Update()
 
         self.pipeline = utils.OperationNode(
-            "extract_cells_on_cylinder", parents=[self],
-            comment=f"#cells {self._data.GetNumberOfCells()}", c='#9e2a2b',
+            "extract_cells_on_cylinder",
+            parents=[self],
+            comment=f"#cells {self._data.GetNumberOfCells()}",
+            c="#9e2a2b",
         )
         self._update(bf.GetOutput())
         return self
@@ -2366,28 +2475,24 @@ class BaseGrid(BaseActor):
         cl.ProduceMergeMapOff()
         cl.AveragePointDataOff()
         cl.Update()
-        
+
         self._update(cl.GetOutput())
         self.pipeline = utils.OperationNode(
-            "clean", parents=[self],
-            comment=f"#cells {self._data.GetNumberOfCells()}",
-            c='#9e2a2b',
+            "clean", parents=[self], comment=f"#cells {self._data.GetNumberOfCells()}", c="#9e2a2b"
         )
         return self
 
-
     def find_cell(self, p):
         """Locate the cell that contains a point and return the cell ID."""
         cell = vtk.vtkTetra()
         cellId = vtk.mutable(0)
         tol2 = vtk.mutable(0)
         subId = vtk.mutable(0)
-        pcoords = [0,0,0]
-        weights = [0,0,0]
+        pcoords = [0, 0, 0]
+        weights = [0, 0, 0]
         cid = self._data.FindCell(p, cell, cellId, tol2, subId, pcoords, weights)
         return cid
 
-
     def extract_cells_by_id(self, idlist, use_point_ids=False):
         """Return a new UGrid composed of the specified subset of indices."""
         selectionNode = vtk.vtkSelectionNode()
@@ -2420,7 +2525,8 @@ class BaseGrid(BaseActor):
         ug.SetPosition(self.GetPosition())
         ug.mapper().SetLookupTable(utils.ctf2lut(self))
         ug.pipeline = utils.OperationNode(
-            "extract_cells_by_id", parents=[self],
+            "extract_cells_by_id",
+            parents=[self],
             comment=f"#cells {self._data.GetNumberOfCells()}",
             c="#9e2a2b",
         )
@@ -2493,7 +2599,7 @@ def probe_line(dataset, p1, p2, res=100):
         - [probe_line1.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/probe_line1.py)
         - [probe_line2.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/probe_line2.py)
 
-            ![](https://vedo.embl.es/images/volumetric/probeLine2.png) 
+            ![](https://vedo.embl.es/images/volumetric/probeLine2.png)
     """
     line = vtk.vtkLineSource()
     line.SetResolution(res)
@@ -2517,8 +2623,8 @@ def probe_plane(dataset, origin=(0, 0, 0), normal=(1, 0, 0)):
     and probes its scalars on a plane defined by a point and a normal.
 
     Examples:
-        - [slicePlane1.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/slicePlane1.py)
-        - [slicePlane2.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/slicePlane2.py)
+        - [slice_plane1.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/slice_plane1.py)
+        - [slice_plane2.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/slice_plane2.py)
 
             ![](https://vedo.embl.es/images/volumetric/slicePlane2.png)
     """
@@ -2535,4 +2641,3 @@ def probe_plane(dataset, origin=(0, 0, 0), normal=(1, 0, 0)):
     cutmesh.name = "ProbePlane"
     cutmesh.pipeline = utils.OperationNode("probe_plane", parents=[dataset])
     return cutmesh
-
