@@ -37,7 +37,7 @@ from vedo.utils import humansort
 from vedo.utils import is_sequence
 from vedo.utils import print_info
 from vedo import __version__
-from vedo import io
+from vedo import file_io
 from vedo import load
 from vedo import settings
 from vedo.colors import get_color, printc
@@ -86,7 +86,10 @@ def execute_cli():
 
     elif len(args.files) == 0:
         system_info()
-        printc("No input files. Try:\n> vedo https://vedo.embl.es/examples/data/panther.stl.gz", c="y")
+        printc(
+            ":idea: No input files. Try:\n> vedo https://vedo.embl.es/examples/data/panther.stl.gz",
+            c="y",
+        )
 
     else:
         draw_scene(args)
@@ -115,7 +118,7 @@ def get_parser():
     pr.add_argument("-bg2", "--background-grad",    help="use background color gradient", default='', metavar='')
     pr.add_argument("-z", "--zoom", type=float,     help="zooming factor", default=1, metavar='')
     pr.add_argument("-n", "--multirenderer-mode",   help="multi renderer mode: files go to separate renderers", action="store_true")
-    pr.add_argument("-s", "--scrolling-mode",       help="scrolling Mode: use slider to scroll files", action="store_true")
+    pr.add_argument("-s", "--sequence-mode",        help="sequence mode: use slider to browse files", action="store_true")
     pr.add_argument("-g", "--ray-cast-mode",        help="GPU Ray-casting Mode for 3D image files", action="store_true")
     pr.add_argument("-gx", "--x-spacing", type=float, help="volume x-spacing factor [1]", default=1, metavar='')
     pr.add_argument("-gy", "--y-spacing", type=float, help="volume y-spacing factor [1]", default=1, metavar='')
@@ -183,9 +186,7 @@ def system_info():
             pr = "         "
             if m.is_primary:
                 pr = "(primary)"
-            printc(
-                f"monitor {pr} : {m.name}, resolution=({m.width}, {m.height}), x={m.x}, y={m.y}"
-            )
+            printc(f"monitor {pr} : {m.name}, resolution=({m.width}, {m.height}), x={m.x}, y={m.y}")
     except ModuleNotFoundError:
         printc('monitor           : info is unavailable. Try "pip install screeninfo".')
 
@@ -196,12 +197,6 @@ def system_info():
     except ModuleNotFoundError:
         pass
 
-    try:
-        import ipyvtk_simple
-
-        printc("ipyvtk version    :", ipyvtk_simple.__version__, bold=0, dim=1)
-    except ModuleNotFoundError:
-        pass
     # try:
     #     import trame
     #     printc("trame version     :", trame.__version__, bold=0, dim=1)
@@ -217,30 +212,35 @@ def exe_run(args):
     matching = [
         s
         for s in exfiles
-        if (f2search in os.path.basename(s).lower() 
-            and "__" not in s and "dolfin" not in s and "trimesh" not in s
+        if (
+            f2search in os.path.basename(s).lower()
+            and "__" not in s
+            and "dolfin" not in s
+            and "trimesh" not in s
         )
     ]
     matching = list(sorted(matching))
     nmat = len(matching)
     if nmat == 0:
-        printc("No matching example found containing string:", args.run, c=1)
+        printc(f":sad: No matching example found containing string: {args.run}", c=1)
         printc(" Current installation directory is:", vedo.installdir, c=1)
         sys.exit(1)
 
     if nmat > 1:
-        printc("\nSelect one of", nmat, "matching scripts:", c="y", italic=1)
+        printc(f"\n:target: Found {nmat} matching scripts:", c="y", italic=1)
         args.full_screen = True  # to print out the one line description
 
     if args.full_screen:  # -f option not to dump the full code but just the first line
         for mat in matching[:25]:
             printc(os.path.basename(mat).replace(".py", ""), c="y", italic=1, end=" ")
-            with open(mat, 'r', encoding='UTF-8') as fm:
-                lline = ''.join(fm.readlines(60))
-                lline = lline.replace('\n',' ').replace('\'','').replace('\"','').replace('-','')
-                line = lline[:56] #cut
-                if line.startswith('from'): line=''
-                if line.startswith('import'): line=''
+            with open(mat, "r", encoding="UTF-8") as fm:
+                lline = "".join(fm.readlines(60))
+                lline = lline.replace("\n", " ").replace("'", "").replace('"', "").replace("-", "")
+                line = lline[:56]  # cut
+                if line.startswith("from"):
+                    line = ""
+                if line.startswith("import"):
+                    line = ""
                 if len(lline) > len(line):
                     line += ".."
                 if len(line) > 5:
@@ -300,7 +300,7 @@ def exe_convert(args):
     target_ext = args.to.lower()
 
     if target_ext not in allowedexts:
-        printc("Sorry target cannot be", target_ext, "\nMust be", allowedexts, c=1)
+        printc(f":sad: Sorry target cannot be {target_ext}\nMust be {allowedexts}", c=1)
         sys.exit()
 
     for f in args.convert:
@@ -339,13 +339,25 @@ def exe_search(args):
                             name = os.path.basename(ifile)
                             try:
                                 etype = ifile.split("/")[-2]
-                                printc("--> examples/"+etype+"/"+name+":", c='y', italic=1, invert=1)
+                                printc(
+                                    "--> examples/" + etype + "/" + name + ":",
+                                    c="y",
+                                    italic=1,
+                                    invert=1,
+                                )
                             except IndexError:
                                 etype = ifile.split("\\")[-2]
-                                printc("--> examples\\"+etype+"\\"+name+":", c='y', italic=1, invert=1)
+                                printc(
+                                    "--> examples\\" + etype + "\\" + name + ":",
+                                    c="y",
+                                    italic=1,
+                                    invert=1,
+                                )
                             fflag = False
-                        line = line.replace(pattern, "\x1b[4m\x1b[1m"+pattern+"\x1b[0m\u001b[33m")
-                        print(f"\u001b[33m{i}\t{line}\x1b[0m", end='')
+                        line = line.replace(
+                            pattern, "\x1b[4m\x1b[1m" + pattern + "\x1b[0m\u001b[33m"
+                        )
+                        print(f"\u001b[33m{i}\t{line}\x1b[0m", end="")
                         # printc(i, line, c='o', bold=False, end='')
     else:
         printc("Please use at least 4 letters in keyword search!", c="r")
@@ -408,7 +420,7 @@ def exe_search_code(args):
                 snames.append(sname)
 
                 printc(
-                    "Found matching",
+                    ":checked:Found matching",
                     mm,
                     "in module",
                     os.path.basename(inspect.getfile(mm)),
@@ -417,15 +429,11 @@ def exe_search_code(args):
                 )
                 mmdoc = mmdoc.replace("``", '"').replace("`", '"')
                 mmdoc = mmdoc.replace(".. warning::", "Warning!")
-                result = highlight(
-                    mmdoc,
-                    Python3Lexer(),
-                    Terminal256Formatter(style=style),
-                )
+                result = highlight(mmdoc, Python3Lexer(), Terminal256Formatter(style=style))
                 idcomment = result.rfind('"""')
                 print(result[: idcomment + 3], "\x1b[0m\n")
 
-    printc("..parsing source code, please wait", c="y", bold=False)
+    # printc("..parsing source code, please wait", c="y", bold=False)
     content = inspect.getmembers(vedo)
     snames = []
     for name, m in content:
@@ -477,7 +485,7 @@ def exe_search_vtk(args):
         try:
             kv = d[vtk_class][lang].items()
         except KeyError as e:
-            print(f'For the combination {vtk_class} and {lang}, this key does not exist: {e}')
+            print(f"For the combination {vtk_class} and {lang}, this key does not exist: {e}")
             return None, None
         total = len(kv)
         samples = list(kv)
@@ -568,8 +576,8 @@ def exe_eog(args):
                 ahl = plt.hover_legends[-1]
                 plt.remove(ahl)
                 plt.screenshot()  # writer
-                printc("Picture saved as screenshot.png")
-                plt.add(ahl, render=False)
+                printc(":camera: Picture saved as screenshot.png")
+                plt.add(ahl)
                 return
             elif event.keypress == "h":
                 printc("---------------------------------------------")
@@ -635,9 +643,7 @@ def exe_eog(args):
             shape[0] = shape[0] / shape[1] * 1200
             shape[1] = 1200
 
-        plt = Plotter(
-            title=files[0], size=shape, bg=args.background, bg2=args.background_grad
-        )
+        plt = Plotter(title=files[0], size=shape, bg=args.background, bg2=args.background_grad)
         plt.add_callback("key press", vfunc)
         plt.add_hover_legend(c="k8", bg="k2", alpha=0.4)
         plt.show(pic, mode="image", interactive=False)
@@ -677,22 +683,26 @@ def draw_scene(args):
         applications.Browser(frames).show(bg=args.background, bg2=args.background_grad)
         return  ##########################################################
 
-    if args.scrolling_mode:
+    if args.sequence_mode:
         args.multirenderer_mode = False
     settings.default_font = args.font
 
+    sharecam = args.no_camera_share
+
     N = None
     if args.multirenderer_mode:
         if nfiles < 201:
             N = nfiles
         if nfiles > 200:
-            printc("Warning: option '-n' allows a maximum of 200 files", c=1)
+            printc(":lightning: Warning: option '-n' allows a maximum of 200 files", c=1)
             printc("         you are trying to load ", nfiles, " files.\n", c=1)
             N = 200
         if N > 4:
             settings.use_depth_peeling = False
 
-        plt = Plotter(size=wsize, N=N, bg=args.background, bg2=args.background_grad)
+        plt = Plotter(size=wsize, N=N, 
+                      bg=args.background, bg2=args.background_grad,
+                      sharecam=sharecam)
         settings.immediate_rendering = False
         plt.axes = args.axes_type
         for i in range(N):
@@ -705,8 +715,6 @@ def draw_scene(args):
         plt.axes = args.axes_type
         plt.add_hover_legend()
 
-    plt.sharecam = not args.no_camera_share
-
     wire = False
     if args.wireframe:
         wire = True
@@ -716,14 +724,14 @@ def draw_scene(args):
     if args.ray_cast_mode:
         # print('DEBUG special case of SLC/TIFF volumes with -g option')
 
-        vol = io.load(args.files[0], force=args.reload)
+        vol = file_io.load(args.files[0], force=args.reload)
 
         if not isinstance(vol, Volume):
             vedo.logger.error(f"expected a Volume but loaded a {type(vol)} object")
             return
 
         sp = vol.spacing()
-        vol.spacing([sp[0]*args.x_spacing, sp[1]*args.y_spacing, sp[2]*args.z_spacing])
+        vol.spacing([sp[0] * args.x_spacing, sp[1] * args.y_spacing, sp[2] * args.z_spacing])
         vol.mode(int(args.mode)).color(args.cmap).jittering(True)
         vol.lighting(args.lighting)
         plt = applications.RayCastPlotter(vol)
@@ -742,12 +750,10 @@ def draw_scene(args):
             args.axes_type = 1
             useSlider3D = True
 
-        vol = io.load(args.files[0], force=args.reload)
+        vol = file_io.load(args.files[0], force=args.reload)
 
         sp = vol.spacing()
-        vol.spacing(
-            [sp[0] * args.x_spacing, sp[1] * args.y_spacing, sp[2] * args.z_spacing]
-        )
+        vol.spacing([sp[0] * args.x_spacing, sp[1] * args.y_spacing, sp[2] * args.z_spacing])
 
         vedo.plotter_instance = None  # reset
 
@@ -773,7 +779,9 @@ def draw_scene(args):
         try:
             m = Mesh(args.files[0], alpha=args.alpha / 2, c=args.color)
         except AttributeError:
-            vedo.logger.critical("In edit mode, input file must be a point cloud or polygonal mesh.")
+            vedo.logger.critical(
+                "In edit mode, input file must be a point cloud or polygonal mesh."
+            )
             return
 
         plt = applications.FreeHandCutPlotter(m, splined=True)
@@ -785,13 +793,13 @@ def draw_scene(args):
     ########################################################################
     elif args.slicer2d:
         # print('DEBUG special case of SLC/TIFF/DICOM volumes with --slicer2d option')
-        vol = io.load(args.files[0], force=args.reload)
+        vol = file_io.load(args.files[0], force=args.reload)
         if not vol:
             return
         vol.cmap("bone_r")
         sp = vol.spacing()
-        vol.spacing([sp[0]*args.x_spacing, sp[1]*args.y_spacing, sp[2]*args.z_spacing])
-        vedo.plotter_instance = None # reset
+        vol.spacing([sp[0] * args.x_spacing, sp[1] * args.y_spacing, sp[2] * args.z_spacing])
+        vedo.plotter_instance = None  # reset
 
         plt = applications.Slicer2DPlotter(vol, axes=7)
         plt.close()
@@ -808,26 +816,23 @@ def draw_scene(args):
         or ".dem" in args.files[0].lower()
     ):
         # print('DEBUG normal mode for single VOXEL file with Isosurface Slider mode')
-        vol = io.load(args.files[0], force=args.reload)
+        vol = file_io.load(args.files[0], force=args.reload)
         sp = vol.spacing()
-        vol.spacing(
-            [sp[0] * args.x_spacing, sp[1] * args.y_spacing, sp[2] * args.z_spacing]
-        )
+        vol.spacing([sp[0] * args.x_spacing, 
+                     sp[1] * args.y_spacing, 
+                     sp[2] * args.z_spacing])
         if not args.color:
             args.color = "gold"
         plt = applications.IsosurfaceBrowser(
-            vol,
-            c=args.color,
-            cmap=args.cmap,
-            precompute=True,
-            progress=True,
+            vol, c=args.color, cmap=args.cmap, 
+            precompute=False, progress=True, use_gpu=True,
         )
         plt.show(zoom=args.zoom, viewup="z")
         return
 
     ########################################################################
     # NORMAL mode for single or multiple files, or multiren mode, or numpy scene
-    elif nfiles == 1 or (not args.scrolling_mode):
+    elif nfiles == 1 or (not args.sequence_mode):
         # print('DEBUG NORMAL mode for single or multiple files, or multiren mode')
 
         interactor_mode = 0
@@ -838,7 +843,7 @@ def draw_scene(args):
         # loading a full scene
         if ".npy" in args.files[0] or ".npz" in args.files[0] and nfiles == 1:
 
-            objct = io.load(args.files[0], force=args.reload)
+            objct = file_io.load(args.files[0], force=args.reload)
             if isinstance(objct, Plotter):  # loading a full scene
                 objct.show(mode=interactor_mode)
             else:  # loading a set of meshes
@@ -891,7 +896,8 @@ def draw_scene(args):
                 try:
                     ds = actor.diagonal_size() * 3
                     plt.camera.SetClippingRange(0, ds)
-                    plt.show(actor, at=i, interactive=False, zoom=args.zoom, mode=interactor_mode)
+                    plt.show(actor, at=i, interactive=False,
+                             zoom=args.zoom, mode=interactor_mode)
                     plt.actors = actors
                 except AttributeError:
                     # wildcards in quotes make glob return actor as a list :(
@@ -908,12 +914,11 @@ def draw_scene(args):
             if all(a is None for a in actors):
                 vedo.logger.error("Could not load file(s). Quit.")
                 return
-
             plt.show(actors, interactive=True, zoom=args.zoom, mode=interactor_mode)
         return
 
     ########################################################################
-    # scrolling mode  -s
+    # sequence mode  -s
     else:
         # print("DEBUG simple browser mode  -s")
         if plt.axes == 4:
