@@ -4,6 +4,7 @@ import os
 
 __docformat__ = "google"
 
+
 class Settings:
     """
     General settings to modify the global behavior
@@ -24,15 +25,13 @@ class Settings:
     # Palette number when using an integer to choose a color
     palette = 0
 
-    # Scale magnification of the screenshot (must be an integer)
-    screeshot_scale = 1
     screenshot_transparent_background = False
     screeshot_large_image = False # Sometimes setting this to True gives better results
 
     # [DISABLED] Allow to continuously interact with scene during interactive() execution
     allow_interaction = True
 
-    # enable tracking pipeline functionality: 
+    # Enable tracking pipeline functionality: 
     #  allows to show a graph with the pipeline of action which let to a final object
     #  this is achieved by calling "myobj.pipeline.show()" (a new window will pop up)
     self.enable_pipeline = True
@@ -118,10 +117,11 @@ class Settings:
     k3d_menu_visibility = True
     k3d_plot_height = 512
     k3d_antialias   = True
-    k3d_lighting    = 1.2
+    k3d_lighting    = 1.5
     k3d_camera_autofit = True
     k3d_grid_autofit= True
-    k3d_axes_helper = True    # size of the small triad of axes on the bottom right
+    k3d_axes_color  = "gray4"
+    k3d_axes_helper = 1.0     # size of the small triad of axes on the bottom right
     k3d_point_shader= "mesh"  # others are '3d', '3dSpecular', 'dot', 'flat'
     k3d_line_shader = "thick" # others are 'flat', 'mesh'
     ```
@@ -134,7 +134,6 @@ class Settings:
         "default_backend",
         "palette",
         "remember_last_figure_format",
-        "screeshot_scale",
         "screenshot_transparent_background",
         "screeshot_large_image",
         "allow_interaction",
@@ -181,6 +180,7 @@ class Settings:
         "k3d_lighting",
         "k3d_camera_autofit",
         "k3d_grid_autofit",
+        "k3d_axes_color",
         "k3d_axes_helper",
         "k3d_point_shader",
         "k3d_line_shader",
@@ -188,7 +188,6 @@ class Settings:
     ]
 
     def __init__(self, level=0):
-        """Contructor."""
 
         self._level = level
 
@@ -215,8 +214,6 @@ class Settings:
 
         self.remember_last_figure_format = False
 
-        # Scale magnification of the screenshot (must be an integer)
-        self.screeshot_scale = 1
         self.screenshot_transparent_background = False
         self.screeshot_large_image = False
 
@@ -295,9 +292,9 @@ class Settings:
 
         # AnnotatedCube axis (type 5) customization:
         self.annotated_cube_color = (0.75, 0.75, 0.75)
-        self.annotated_cube_text_color = None # use default, otherwise specify a single color
+        self.annotated_cube_text_color = None  # use default, otherwise specify a single color
         self.annotated_cube_text_scale = 0.2
-        self.annotated_cube_texts = ["right","left ", "front","back ", " top ", "bttom"]
+        self.annotated_cube_texts = ["right", "left ", "front", "back ", " top ", "bttom"]
 
         # enable / disable color printing
         self.enable_print_color = True
@@ -311,10 +308,11 @@ class Settings:
         self.k3d_menu_visibility = True
         self.k3d_plot_height = 512
         self.k3d_antialias  = True
-        self.k3d_lighting   = 1.2
+        self.k3d_lighting   = 1.5
         self.k3d_camera_autofit = True
         self.k3d_grid_autofit= True
-        self.k3d_axes_helper = True    # size of the small triad of axes on the bottom right
+        self.k3d_axes_color  = "k4"
+        self.k3d_axes_helper = 1.0     # size of the small triad of axes on the bottom right
         self.k3d_point_shader= "mesh"  # others are '3d', '3dSpecular', 'dot', 'flat'
         self.k3d_line_shader = "thick" # others are 'flat', 'mesh'
 
@@ -331,7 +329,7 @@ class Settings:
                 fscale=0.75,
                 hspacing=1,
                 lspacing=0.2,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=True,
             ),
             Bongas=dict(
@@ -347,7 +345,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=1,
                 lspacing=0.1,
-                dotsep="·",
+                dotsep="×",
                 islocal=True,
             ),
             Comae=dict(
@@ -355,7 +353,7 @@ class Settings:
                 fscale=0.75,
                 lspacing=0.2,
                 hspacing=1,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=True,
             ),
             ComicMono=dict(
@@ -363,7 +361,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=1,
                 lspacing=0.1,
-                dotsep="·",
+                dotsep="x",
                 islocal=False,
             ),
             Edo=dict(
@@ -371,7 +369,7 @@ class Settings:
                 fscale=0.75,
                 hspacing=1,
                 lspacing=0.2,
-                dotsep="·~~",
+                dotsep="~x ",
                 islocal=False,
             ),
             FiraMonoMedium=dict(
@@ -379,7 +377,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=1,
                 lspacing=0.1,
-                dotsep="·",
+                dotsep="×",
                 islocal=False,
             ),
             FiraMonoBold=dict(
@@ -387,7 +385,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=1,
                 lspacing=0.1,
-                dotsep="·",
+                dotsep="×",
                 islocal=False,
             ),
             Glasgo=dict(
@@ -395,7 +393,7 @@ class Settings:
                 fscale=0.75,
                 lspacing=0.1,
                 hspacing=1,
-                dotsep="·",
+                dotsep="~×",
                 islocal=True,
             ),
             Kanopus=dict(
@@ -403,7 +401,7 @@ class Settings:
                 fscale=0.75,
                 lspacing=0.15,
                 hspacing=0.75,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=True,
             ),
             LogoType=dict(
@@ -411,7 +409,7 @@ class Settings:
                 fscale=0.75,
                 hspacing=1,
                 lspacing=0.2,
-                dotsep="·~~",
+                dotsep="~×",
                 islocal=False,
             ),
             Quikhand=dict(
@@ -419,7 +417,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=0.6,
                 lspacing=0.15,
-                dotsep="~~·~",
+                dotsep="~~×~",
                 islocal=True,
             ),
             SmartCouric=dict(
@@ -427,7 +425,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=1.05,
                 lspacing=0.1,
-                dotsep="·",
+                dotsep="×",
                 islocal=True,
             ),
             Spears=dict(
@@ -435,7 +433,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=0.5,
                 lspacing=0.2,
-                dotsep="·",
+                dotsep="~×",
                 islocal=False,
             ),
             Theemim=dict(
@@ -443,7 +441,7 @@ class Settings:
                 fscale=0.825,
                 hspacing=0.52,
                 lspacing=0.3,
-                dotsep="~·",
+                dotsep="~~×",
                 islocal=True,
             ),
             VictorMono=dict(
@@ -451,7 +449,7 @@ class Settings:
                 fscale=0.725,
                 hspacing=1,
                 lspacing=0.1,
-                dotsep="·",
+                dotsep="×",
                 islocal=True,
             ),
             Justino1=dict(
@@ -459,7 +457,7 @@ class Settings:
                 fscale=0.725,
                 hspacing=1,
                 lspacing=0.1,
-                dotsep="·",
+                dotsep="×",
                 islocal=False,
             ),
             Justino2=dict(
@@ -467,7 +465,7 @@ class Settings:
                 fscale=0.725,
                 hspacing=1,
                 lspacing=0.1,
-                dotsep="·",
+                dotsep="×",
                 islocal=False,
             ),
             Justino3=dict(
@@ -475,7 +473,7 @@ class Settings:
                 fscale=0.725,
                 hspacing=1,
                 lspacing=0.1,
-                dotsep="·",
+                dotsep="×",
                 islocal=False,
             ),
             Calibri=dict(
@@ -483,7 +481,7 @@ class Settings:
                 fscale=0.75,
                 hspacing=1,
                 lspacing=0.2,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=False,
             ),
             Capsmall=dict(
@@ -491,7 +489,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=0.75,
                 lspacing=0.15,
-                dotsep="·",
+                dotsep="~×",
                 islocal=False,
             ),
             Cartoons123=dict(
@@ -499,7 +497,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=0.75,
                 lspacing=0.15,
-                dotsep="·",
+                dotsep="x",
                 islocal=False,
             ),
             Vega=dict(
@@ -507,7 +505,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=0.75,
                 lspacing=0.15,
-                dotsep="·",
+                dotsep="×",
                 islocal=False,
             ),
             Meson=dict(
@@ -515,7 +513,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=0.9,
                 lspacing=0.225,
-                dotsep="~^.~ ",
+                dotsep="~×",
                 islocal=False,
             ),
             Komika=dict(
@@ -523,7 +521,7 @@ class Settings:
                 fscale=0.7,
                 hspacing=0.75,
                 lspacing=0.225,
-                dotsep="~^.~ ",
+                dotsep="~×",
                 islocal=False,
             ),
             Vogue=dict(
@@ -531,7 +529,7 @@ class Settings:
                 fscale=0.7,
                 hspacing=0.75,
                 lspacing=0.225,
-                dotsep="~^.~ ",
+                dotsep="~x",
                 islocal=False,
             ),
             Brachium=dict(
@@ -539,7 +537,7 @@ class Settings:
                 fscale=0.8,
                 hspacing=1,
                 lspacing=0.1,
-                dotsep="·",
+                dotsep="x",
                 islocal=False,
             ),
             Dalim=dict(
@@ -547,7 +545,7 @@ class Settings:
                 fscale=0.75,
                 lspacing=0.2,
                 hspacing=1,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=False,
             ),
             Miro=dict(
@@ -555,7 +553,7 @@ class Settings:
                 fscale=0.75,
                 lspacing=0.2,
                 hspacing=1,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=False,
             ),
             Ubuntu=dict(
@@ -563,7 +561,7 @@ class Settings:
                 fscale=0.75,
                 lspacing=0.2,
                 hspacing=1,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=False,
             ),
             Mizar=dict(
@@ -571,7 +569,7 @@ class Settings:
                 fscale=0.75,
                 lspacing=0.2,
                 hspacing=0.75,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=False,
             ),
             LiberationSans=dict(
@@ -579,7 +577,7 @@ class Settings:
                 fscale=0.75,
                 lspacing=0.2,
                 hspacing=1,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=False,
             ),
             DejavuSansMono=dict(
@@ -587,7 +585,7 @@ class Settings:
                 fscale=0.725,
                 hspacing=1,
                 lspacing=0.1,
-                dotsep="·",
+                dotsep="~×",
                 islocal=False,
             ),
             SunflowerHighway=dict(
@@ -595,7 +593,7 @@ class Settings:
                 fscale=0.75,
                 lspacing=0.2,
                 hspacing=1,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=False,
             ),
             Swansea=dict(
@@ -603,7 +601,7 @@ class Settings:
                 fscale=0.75,
                 lspacing=0.2,
                 hspacing=1,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=False,
             ),
             Housekeeper=dict(  # support chinese glyphs
@@ -611,7 +609,7 @@ class Settings:
                 fscale=0.75,
                 hspacing=1,
                 lspacing=0.2,
-                dotsep="~·",
+                dotsep="~×",
                 islocal=False,
             ),
             Wananti=dict(  # support chinese glyphs
@@ -619,7 +617,7 @@ class Settings:
                 fscale=0.75,
                 hspacing=1,
                 lspacing=0.2,
-                dotsep="~·",
+                dotsep="~x",
                 islocal=False,
             ),
             AnimeAce=dict(
@@ -627,7 +625,7 @@ class Settings:
                 fscale=0.75,
                 hspacing=1,
                 lspacing=0.2,
-                dotsep="~·",
+                dotsep="~x",
                 islocal=False,
             ),
             AnimeAceBold=dict(
@@ -635,7 +633,7 @@ class Settings:
                 fscale=0.75,
                 hspacing=1,
                 lspacing=0.2,
-                dotsep="~·",
+                dotsep="~x",
                 islocal=False,
             ),
         )
@@ -647,24 +645,20 @@ class Settings:
 
     def print(self):
         """Print function."""
-        print(' ' + '-'*80)
-        s = Settings.__doc__.replace('   ','')
-        s = s.replace(".. code-block:: python\n","")
+        print(" " + "-" * 80)
+        s = Settings.__doc__.replace("   ", "")
+        s = s.replace(".. code-block:: python\n", "")
         try:
             from pygments import highlight
             from pygments.lexers import Python3Lexer
             from pygments.formatters import Terminal256Formatter
-            s = highlight(s, Python3Lexer(), Terminal256Formatter(style='zenburn'))
-            print(s, end='')
+
+            s = highlight(s, Python3Lexer(), Terminal256Formatter(style="zenburn"))
+            print(s, end="")
 
         except ModuleNotFoundError:
             print("\x1b[33;1m" + s + "\x1b[0m")
 
-
-    def _warn(self, key):
-        if self._level == 0:
-            print(f'\x1b[1m\x1b[33;20m Warning! Please use "settings.{key}" instead!\x1b[0m')
-
     def __getitem__(self, key):
         """Make the class work like a dictionary too"""
         return getattr(self, key)
@@ -674,258 +668,60 @@ class Settings:
         setattr(self, key, value)
 
 
-    ####################################################################################
-    # Deprecations
-    ####################################################################################
-    @property
-    def defaultFont(self):
-        self._warn("default_font")
-        return self.default_font
-    @defaultFont.setter
-    def defaultFont(self, value):
-        self._warn("default_font")
-        self.default_font = value
-    ##################################
-    @property
-    def screeshotScale(self):
-        self._warn("screeshot_scale")
-        return self.screeshot_scale
-    @screeshotScale.setter
-    def screeshotScale(self, value):
-        self._warn("screeshot_scale")
-        self.screeshot_scale = value
-    ##################################
-    @property
-    def screenshotTransparentBackground(self):
-        self._warn("screenshot_transparent_background")
-        return self.NAME_SNAKE
-    @screenshotTransparentBackground.setter
-    def screenshotTransparentBackground(self, value):
-        self._warn("screenshot_transparent_background")
-        self.screenshot_transparent_background = value
-    ##################################
-    @property
-    def screeshotLargeImage(self):
-        self._warn("screeshot_large_image")
-        return self.screeshot_large_image
-    @screeshotLargeImage.setter
-    def screeshotLargeImage(self, value):
-        self._warn("screeshot_large_image")
-        self.screeshot_large_image = value
-    ##################################
-    @property
-    def allowInteraction(self):
-        self._warn("allow_interaction")
-        return self.allow_interaction
-    @allowInteraction.setter
-    def allowInteraction(self, value):
-        self._warn("allow_interaction")
-        self.allow_interaction = value
-    ##################################
-    @property
-    def enableDefaultMouseCallbacks(self):
-        self._warn("enable_default_mouse_callbacks")
-        return self.enable_default_mouse_callbacks
-    @enableDefaultMouseCallbacks.setter
-    def enableDefaultMouseCallbacks(self, value):
-        self._warn("enable_default_mouse_callbacks")
-        self.enable_default_mouse_callbacks = value
-    ##################################
-    @property
-    def enableDefaultKeyboardCallbacks(self):
-        self._warn("enable_default_keyboard_callbacks")
-        return self.enable_default_keyboard_callbacks
-    @enableDefaultKeyboardCallbacks.setter
-    def enableDefaultKeyboardCallbacks(self, value):
-        self._warn("enable_default_keyboard_callbacks")
-        self.enable_default_keyboard_callbacks = value
-    ##################################
-    @property
-    def immediateRendering(self):
-        self._warn("immediate_rendering")
-        return self.immediate_rendering
-    @immediateRendering.setter
-    def immediateRendering(self, value):
-        self._warn("immediate_rendering")
-        self.immediate_rendering = value
-    ##################################
-    @property
-    def renderLinesAsTubes(self):
-        self._warn("render_lines_as_tubes")
-        return self.render_lines_as_tubes
-    @renderLinesAsTubes.setter
-    def renderLinesAsTubes(self, value):
-        self._warn("render_lines_as_tubes")
-        self.render_lines_as_tubes = value
-    ##################################
-    @property
-    def hiddenLineRemoval(self):
-        self._warn("hidden_line_removal")
-        return self.hidden_line_removal
-    @hiddenLineRemoval.setter
-    def hiddenLineRemoval(self, value):
-        self._warn("hidden_line_removal")
-        self.hidden_line_removal = value
-    ##################################
-    @property
-    def pointSmoothing(self):
-        self._warn("point_smoothing")
-        return self.point_smoothing
-    @pointSmoothing.setter
-    def pointSmoothing(self, value):
-        self._warn("point_smoothing")
-        self.point_smoothing = value
-    ##################################
-    @property
-    def lightFollowsCamera(self):
-        self._warn("light_follows_camera")
-        return self.light_follows_camera
-    @lightFollowsCamera.setter
-    def lightFollowsCamera(self, value):
-        self._warn("light_follows_camera")
-        self.light_follows_camera = value
-    ##################################
-    @property
-    def twoSidedLighting(self):
-        self._warn("two_sided_lighting")
-        return self.two_sided_lighting
-    @twoSidedLighting.setter
-    def twoSidedLighting(self, value):
-        self._warn("two_sided_lighting")
-        self.two_sided_lighting = value
-    ##################################
-    @property
-    def useDepthPeeling(self):
-        self._warn("use_depth_peeling")
-        return self.use_depth_peeling
-    @useDepthPeeling.setter
-    def useDepthPeeling(self, value):
-        self._warn("use_depth_peeling")
-        self.use_depth_peeling = value
-    ##################################
-    @property
-    def multiSamples(self):
-        self._warn("multi_samples")
-        return self.multi_samples
-    @multiSamples.setter
-    def multiSamples(self, value):
-        self._warn("multi_samples")
-        self.multi_samples = value
-    ##################################
-    @property
-    def alphaBitPlanes(self):
-        self._warn("alpha_bit_planes")
-        return self.alpha_bit_planes
-    @alphaBitPlanes.setter
-    def alphaBitPlanes(self, value):
-        self._warn("alpha_bit_planes")
-        self.alpha_bit_planes = value
-    ##################################
-    @property
-    def maxNumberOfPeels(self):
-        self._warn("max_number_of_peels")
-        return self.max_number_of_peels
-    @maxNumberOfPeels.setter
-    def maxNumberOfPeels(self, value):
-        self._warn("max_number_of_peels")
-        self.max_number_of_peels = value
-    ##################################
-    @property
-    def occlusionRatio(self):
-        self._warn("occlusion_ratio")
-        return self.occlusion_ratio
-    @occlusionRatio.setter
-    def occlusionRatio(self, value):
-        self._warn("occlusion_ratio")
-        self.occlusion_ratio = value
-    ##################################
-    @property
-    def useFXAA(self):
-        self._warn("use_fxaa")
-        return self.use_fxaa
-    @useFXAA.setter
-    def useFXAA(self, value):
-        self._warn("use_fxaa")
-        self.use_fxaa = value
-    ##################################
-    @property
-    def preserveDepthBuffer(self):
-        self._warn("preserve_depth_buffer")
-        return self.preserve_depth_buffer
-    @preserveDepthBuffer.setter
-    def preserveDepthBuffer(self, value):
-        self._warn("preserve_depth_buffer")
-        self.preserve_depth_buffer = value
-    ##################################
-    @property
-    def usePolygonOffset(self):
-        self._warn("use_polygon_offset")
-        return self.use_polygon_offset
-    @usePolygonOffset.setter
-    def usePolygonOffset(self, value):
-        self._warn("use_polygon_offset")
-        self.use_polygon_offset = value
-    ##################################
-    @property
-    def polygonOffsetFactor(self):
-        self._warn("polygon_offset_factor")
-        return self.polygon_offset_factor
-    @polygonOffsetFactor.setter
-    def polygonOffsetFactor(self, value):
-        self._warn("polygon_offset_factor")
-        self.polygon_offset_factor = value
-    ##################################
-    @property
-    def polygonOffsetUnits(self):
-        self._warn("polygon_offset_units")
-        return self.polygon_offset_units
-    @polygonOffsetUnits.setter
-    def polygonOffsetUnits(self, value):
-        self._warn("polygon_offset_units")
-        self.polygon_offset_units = value
-    ##################################
-    @property
-    def interpolateScalarsBeforeMapping(self):
-        self._warn("interpolate_scalars_before_mapping")
-        return self.interpolate_scalars_before_mapping
-    @interpolateScalarsBeforeMapping.setter
-    def interpolateScalarsBeforeMapping(self, value):
-        self._warn("interpolate_scalars_before_mapping")
-        self.interpolate_scalars_before_mapping = value
-    ##################################
-    @property
-    def useParallelProjection(self):
-        self._warn("use_parallel_projection")
-        return self.use_parallel_projection
-    @useParallelProjection.setter
-    def useParallelProjection(self, value):
-        self._warn("use_parallel_projection")
-        self.use_parallel_projection = value
-    ##################################
-    @property
-    def windowSplittingPosition(self):
-        self._warn("window_splitting_position")
-        return self.window_splitting_position
-    @windowSplittingPosition.setter
-    def windowSplittingPosition(self, value):
-        self._warn("window_splitting_position")
-        self.window_splitting_position = value
-    ##################################
-    @property
-    def tiffOrientationType(self):
-        self._warn("tiff_orientation_type")
-        return self.tiff_orientation_type
-    @tiffOrientationType.setter
-    def tiffOrientationType(self, value):
-        self._warn("tiff_orientation_type")
-        self.tiff_orientation_type = value
-    ##################################
-    @property
-    def enablePrintColor(self):
-        self._warn("enable_print_color")
-        return self.enable_print_color
-    @enablePrintColor.setter
-    def enablePrintColor(self, value):
-        self._warn("enable_print_color")
-        self.enable_print_color = value
+    def init_colab(self, enable_k3d=True):
+        """
+        Initialize colab environment
+        """
+        print("setting up colab environment (can take a minute) ...", end='')
+
+        res = os.system('which Xvfb')
+        if res:
+            os.system('apt-get install xvfb')
+
+        os.system('pip install pyvirtualdisplay')
+
+        from pyvirtualdisplay import Display
+        Display(visible=0).start()
+
+        if enable_k3d:
+            os.system('pip install k3d')
+
+        from google.colab import output
+        output.enable_custom_widget_manager()
+
+        if enable_k3d:
+            import k3d
+            try:
+                print("installing k3d...", end='')
+                os.system("jupyter nbextension install --py --user k3d")
+                os.system("jupyter nbextension enable  --py --user k3d")
+                k3d.switch_to_text_protocol()
+                self.default_backend = 'k3d'
+                self.backend_autoclose = False
+            except:
+                print("(FAILED) ... ", end='')
+
+        print(" setup completed.")
+
+
+    def start_xvfb(self):
+        """
+        Start xvfb.
+
+        Xvfb or X virtual framebuffer is a display server implementing
+        the X11 display server protocol. In contrast to other display servers,
+        Xvfb performs all graphical operations in virtual memory
+        without showing any screen output.
+        """
+        print("starting xvfb (can take a minute) ...", end='')
+        res = os.system('which Xvfb')
+        if res:
+            os.system('apt-get install xvfb')
+        os.system('set -x')
+        os.system('export DISPLAY=:99.0')
+        os.system('Xvfb :99 -screen 0 1024x768x24 > /dev/null 2>&1 &')
+        os.system('sleep 3')
+        os.system('set +x')
+        os.system('exec "$@"')
+        print(" xvfb started.")
 
