@@ -38,6 +38,7 @@ __all__ = [
     "round_to_digit",
     "point_in_triangle",
     "point_line_distance",
+    "closest",
     "grep",
     "print_info",
     "make_bands",
@@ -67,6 +68,23 @@ __all__ = [
 ]
 
 
+###########################################################################
+array_types = {}
+array_types[vtk.VTK_UNSIGNED_CHAR] = ("UNSIGNED_CHAR",  "np.uint8")
+array_types[vtk.VTK_UNSIGNED_SHORT]= ("UNSIGNED_SHORT", "np.uint16")
+array_types[vtk.VTK_UNSIGNED_INT]  = ("UNSIGNED_INT",   "np.uint32")
+array_types[vtk.VTK_UNSIGNED_LONG_LONG] = ("UNSIGNED_LONG_LONG", "np.uint64")
+array_types[vtk.VTK_CHAR]          = ("CHAR",           "np.int8")
+array_types[vtk.VTK_SHORT]         = ("SHORT",          "np.int16")
+array_types[vtk.VTK_INT]           = ("INT",            "np.int32")
+array_types[vtk.VTK_LONG]          = ("LONG",           "") # ??
+array_types[vtk.VTK_LONG_LONG]     = ("LONG_LONG",      "np.int64")
+array_types[vtk.VTK_FLOAT]         = ("FLOAT",          "np.float32")
+array_types[vtk.VTK_DOUBLE]        = ("DOUBLE",         "np.float64")
+array_types[vtk.VTK_SIGNED_CHAR]   = ("SIGNED_CHAR",    "np.int8")
+array_types[vtk.VTK_ID_TYPE]       = ("ID",             "np.int64")
+
+
 ###########################################################################
 class OperationNode:
     """
@@ -82,13 +100,7 @@ class OperationNode:
     # Assembly #f08080
 
     def __init__(
-        self, 
-        operation,
-        parents=(),
-        comment="",
-        shape="none",
-        c="#e9c46a",
-        style="filled",
+        self, operation, parents=(), comment="", shape="none", c="#e9c46a", style="filled"
     ):
         """
         Keep track of the operations which led to a final object.
@@ -100,16 +112,16 @@ class OperationNode:
         sp.clean().subdivide()
         sp.pipeline.show()
         ```
-        
+
         Arguments:
             operation : (str, class)
-                descriptor label, if a class is passed then grab its name           
+                descriptor label, if a class is passed then grab its name
             parents : (list)
-                list of the parent classes the object comes from           
+                list of the parent classes the object comes from
             comment : (str)
-                a second-line text description      
+                a second-line text description
             shape : (str)
-                shape of the frame, check out [this link.](https://graphviz.org/doc/info/shapes.html)     
+                shape of the frame, check out [this link.](https://graphviz.org/doc/info/shapes.html)
             c : (hex)
                 hex color
             style : (str)
@@ -147,7 +159,7 @@ class OperationNode:
             self.operation = operation.__class__.__name__
         self.operation_plain = str(self.operation)
 
-        pp = [] # filter out invalid stuff
+        pp = []  # filter out invalid stuff
         for p in parents:
             if hasattr(p, "pipeline"):
                 pp.append(p.pipeline)
@@ -161,14 +173,15 @@ class OperationNode:
         self.shape = shape
         self.style = style
         self.color = c
+        self.counts = 0
 
     def add_parent(self, parent):
         self.parents.append(parent)
 
     def _build_tree(self, dot):
         dot.node(
-            str(id(self)), 
-            label=self.operation, 
+            str(id(self)),
+            label=self.operation,
             shape=self.shape,
             color=self.color,
             style=self.style,
@@ -179,12 +192,13 @@ class OperationNode:
                 dot.edge(str(id(parent)), str(id(self)), label=t)
                 parent._build_tree(dot)
 
-    def __repr__(self): 
-        try:      
+    def __repr__(self):
+        try:
             from treelib import Tree
         except ImportError:
-            vedo.logger.error("To use this functionality please install treelib:"
-                              "\n pip install treelib")
+            vedo.logger.error(
+                "To use this functionality please install treelib:" "\n pip install treelib"
+            )
             return ""
 
         def _build_tree(parent):
@@ -192,15 +206,12 @@ class OperationNode:
                 if par:
                     op = par.operation_plain
                     tree.create_node(
-                        op, 
-                        op + str(par.time), 
-                        parent=parent.operation_plain + str(parent.time))
+                        op, op + str(par.time), parent=parent.operation_plain + str(parent.time)
+                    )
                     _build_tree(par)
 
         tree = Tree()
-        tree.create_node(
-            self.operation_plain, self.operation_plain + str(self.time)
-        )
+        tree.create_node(self.operation_plain, self.operation_plain + str(self.time))
         _build_tree(self)
         return tree.show(reverse=True, stdout=False)
 
@@ -208,7 +219,7 @@ class OperationNode:
         """Show the graphviz output for the pipeline of this object"""
         if not vedo.settings.enable_pipeline:
             return
-        
+
         try:
             from graphviz import Digraph
         except ImportError:
@@ -217,23 +228,15 @@ class OperationNode:
 
         # visualize the entire tree
         dot = Digraph(
-            node_attr={
-                'fontcolor':'#201010',
-                'fontname': "Helvetica",
-                'fontsize': '12',
-        },
-            edge_attr={ 
-                'fontname': "Helvetica",
-                'fontsize': '6',
-                'arrowsize': '0.4',
-            }
+            node_attr={"fontcolor": "#201010", "fontname": "Helvetica", "fontsize": "12"},
+            edge_attr={"fontname": "Helvetica", "fontsize": "6", "arrowsize": "0.4"},
         )
         dot.attr(rankdir=orientation)
-        
+
         self.counts = 0
         self._build_tree(dot)
         self.dot = dot
-        dot.render('.vedo_pipeline_graphviz', view=popup)
+        dot.render(".vedo_pipeline_graphviz", view=popup)
 
 
 ###########################################################################
@@ -241,6 +244,7 @@ class ProgressBar:
     """
     Class to print a progress bar.
     """
+
     def __init__(
         self,
         start,
@@ -251,7 +255,7 @@ class ProgressBar:
         italic=False,
         title="",
         eta=True,
-        delay=0,
+        delay=0.0,
         width=25,
         char="\U00002501",
         char_back="\U00002500",
@@ -306,7 +310,7 @@ class ProgressBar:
         """Print the progress bar with an optional message."""
         if not c:
             c = self.color
-        
+
         self._update(self._counts + self.step)
 
         if self.delay:
@@ -391,20 +395,14 @@ class ProgressBar:
             ps = ""
         self.pbar += ps
 
+
 #####################################
-def progressbar(
-        iterable,
-        c=None,
-        bold=True,
-        italic=False,
-        title="",
-        eta=True,
-        width=25,
-        delay=0,
-    ):
+def progressbar(iterable, c=None, bold=True, italic=False, title="", eta=True, width=25, delay=0.5):
     """
     Function to print a progress bar with optional text message.
 
+    Use delay to set a minimum time before printing anything.
+
     Example:
         ```python
         import time
@@ -419,18 +417,18 @@ def progressbar(
             iterable = range(total)
         else:
             total = len(iterable)
-    except TypeError: 
+    except TypeError:
         iterable = list(iterable)
         total = len(iterable)
 
     pb = ProgressBar(
-        0, total, 
-        c=c, bold=bold, italic=italic, title=title, eta=eta, delay=delay, width=width,
+        0, total, c=c, bold=bold, italic=italic, title=title, eta=eta, delay=delay, width=width
     )
     for item in iterable:
         pb.print()
         yield item
 
+
 ###########################################################
 def numpy2vtk(arr, dtype=None, deep=True, name=""):
     """
@@ -481,7 +479,7 @@ def make3d(pts, transpose=False):
     Make an array which might be 2D to 3D.
 
     Array can also be in the form `[allx, ally, allz]`.
-    Use `transpose` to resolve ambigous cases (eg, shapes like `[3,3]`).
+    Use `transpose` to resolve ambiguous cases (eg, shapes like `[3,3]`).
     """
     pts = np.asarray(pts)
 
@@ -541,7 +539,7 @@ def extract_cells_by_type(obj, types=()):
 
     Given an input `vtkDataSet` and a list of cell types, produce an output
     containing only cells of the specified type(s).
-    
+
     Find [here](https://vtk.org/doc/nightly/html/vtkCellType_8h_source.html)
     the list of possible cell types.
 
@@ -550,7 +548,7 @@ def extract_cells_by_type(obj, types=()):
     """
     ef = vtk.vtkExtractCellsByType()
     try:
-        ef.SetInputData(obj._data)
+        ef.SetInputData(obj.inputdata())
     except:
         ef.SetInputData(obj)
 
@@ -710,13 +708,13 @@ def get_font_path(font):
             fl = os.path.join(vedo.fonts_path, f"{font}.ttf")
         else:
             try:
-                fl = vedo.io.download(f"https://vedo.embl.es/fonts/{font}.ttf", verbose=False)
+                fl = vedo.file_io.download(f"https://vedo.embl.es/fonts/{font}.ttf", verbose=False)
             except:
                 vedo.logger.warning(f"Could not download https://vedo.embl.es/fonts/{font}.ttf")
                 fl = os.path.join(vedo.fonts_path, "Normografo.ttf")
     else:
         if font.startswith("https://"):
-            fl = vedo.io.download(font, verbose=False)
+            fl = vedo.file_io.download(font, verbose=False)
         elif os.path.isfile(font):
             fl = font  # assume user is passing a valid file
         else:
@@ -825,7 +823,8 @@ def sort_by_column(arr, nth, invert=False):
 
 def point_in_triangle(p, p1, p2, p3):
     """
-    Return True if a point is inside (or above/below) a triangle defined by 3 points in space.
+    Return True if a point is inside (or above/below)
+    a triangle defined by 3 points in space.
     """
     p1 = np.array(p1)
     u = p2 - p1
@@ -899,6 +898,7 @@ def intersection_ray_triangle(P0, P1, V0, V1, V2):
         return False
     return I  # I is in T
 
+
 def triangle_solver(**input_dict):
     """
     Solve a triangle from any 3 known elements.
@@ -974,7 +974,7 @@ def triangle_solver(**input_dict):
             ac2 = phi + 2 * omega
             ab2 = np.pi - ac2 - bc
             return [
-                {"a": a, "b": b,  "c": c, "ab": ab,  "bc": bc, "ac": ac},
+                {"a": a, "b": b, "c": c, "ab": ab, "bc": bc, "ac": ac},
                 {"a": a, "b": b2, "c": c, "ab": ab2, "bc": bc, "ac": ac2},
             ]
 
@@ -993,7 +993,7 @@ def triangle_solver(**input_dict):
             bc2 = phi + 2 * omega
             ab2 = np.pi - ac - bc2
             return [
-                {"a": a,  "b": b, "c": c, "ab": ab,  "bc": bc,  "ac": ac},
+                {"a": a, "b": b, "c": c, "ab": ab, "bc": bc, "ac": ac},
                 {"a": a2, "b": b, "c": c, "ab": ab2, "bc": bc2, "ac": ac},
             ]
 
@@ -1004,22 +1004,53 @@ def triangle_solver(**input_dict):
     return [{"a": a, "b": b, "c": c, "ab": ab, "bc": bc, "ac": ac}]
 
 
+#############################################################################
 def point_line_distance(p, p1, p2):
     """
     Compute the distance of a point to a line (not the segment)
     defined by `p1` and `p2`.
     """
-    d = np.sqrt(vtk.vtkLine.DistanceToLine(p, p1, p2))
-    return d
+    return np.sqrt(vtk.vtkLine.DistanceToLine(p, p1, p2))
 
 
-def linInterpolate(x, rangeX, rangeY):
-    "Deprecated. Please `lin_interpolate()`"
-    m = "Warning! linInterpolate() is deprecated. Please use lin_interpolate()"
-    print("\x1b[1m\x1b[33;1m " + m + "\x1b[0m")
-    return lin_interpolate(x, rangeX, rangeY)
+def closest(point, points, n=1, return_ids=False, use_tree=False):
+    """
+    Returns the distances and the closest point(s) to the given set of points.
+    Needs `scipy.spatial` library.
+
+    Arguments:
+        n : (int)
+            the nr of closest points to return
+        return_ids : (bool)
+            return the ids instead of the points coordinates
+        use_tree : (bool)
+            build a `scipy.spatial.KDTree`.
+            An already existing one can be passed to avoid rebuilding.
+    """
+    from scipy.spatial import distance, KDTree
+
+    points = np.asarray(points)
+    if n == 1:
+        dists = distance.cdist([point], points)
+        closest_idx = np.argmin(dists)
+    else:
+        if use_tree:
+            if isinstance(use_tree, KDTree):  # reuse
+                tree = use_tree
+            else:
+                tree = KDTree(points)
+            dists, closest_idx = tree.query([point], k=n)
+            closest_idx = closest_idx[0]
+        else:
+            dists = distance.cdist([point], points)
+            closest_idx = np.argsort(dists)[0][:n]
+    if return_ids:
+        return dists, closest_idx
+    else:
+        return dists, points[closest_idx]
 
 
+#############################################################################
 def lin_interpolate(x, rangeX, rangeY):
     """
     Interpolate linearly the variable `x` in `rangeX` onto the new `rangeY`.
@@ -1171,7 +1202,7 @@ def is_integer(n):
     """Check if input is an integer."""
     try:
         float(n)
-    except ValueError:
+    except (ValueError, TypeError):
         return False
     else:
         return float(n).is_integer()
@@ -1182,7 +1213,7 @@ def is_number(n):
     try:
         float(n)
         return True
-    except ValueError:
+    except (ValueError, TypeError):
         return False
 
 
@@ -1196,13 +1227,6 @@ def round_to_digit(x, p):
     return r
 
 
-def packSpheres(bounds, radius):
-    "Deprecated. Please use `pack_spheres()`"
-    m = "Warning! packSpheres() is deprecated. Please use pack_spheres()"
-    print("\x1b[1m\x1b[33;1m " + m + "\x1b[0m")
-    return pack_spheres(bounds, radius)
-
-
 def pack_spheres(bounds, radius):
     """
     Packing spheres into a bounding box.
@@ -1392,7 +1416,7 @@ def spher2cyl(rho, theta, phi):
 
 
 ##################################################################################
-def grep(filename, tag, first_occurrence_only=False):
+def grep(filename, tag, column=None, first_occurrence_only=False):
     """Greps the line in a file that starts with a specific `tag` string inside the file."""
     import re
 
@@ -1402,6 +1426,8 @@ def grep(filename, tag, first_occurrence_only=False):
             if re.search(tag, line):
                 c = line.split()
                 c[-1] = c[-1].replace("\n", "")
+                if column is not None:
+                    c = c[column]
                 content.append(c)
                 if first_occurrence_only:
                     break
@@ -1411,43 +1437,20 @@ def grep(filename, tag, first_occurrence_only=False):
 def print_info(obj):
     """Print information about a `vedo` object."""
 
-    def _print_data(poly, mapper, c):
+    def _print_data(poly, c):
         ptdata = poly.GetPointData()
         cldata = poly.GetCellData()
         fldata = poly.GetFieldData()
         if ptdata.GetNumberOfArrays() + cldata.GetNumberOfArrays():
-            arrtypes = {}
-            arrtypes[vtk.VTK_UNSIGNED_CHAR] = ("UNSIGNED_CHAR",  "np.uint8")
-            arrtypes[vtk.VTK_UNSIGNED_SHORT]= ("UNSIGNED_SHORT", "np.uint16")
-            arrtypes[vtk.VTK_UNSIGNED_INT]  = ("UNSIGNED_INT",   "np.uint32")
-            arrtypes[vtk.VTK_UNSIGNED_LONG_LONG] = ("UNSIGNED_LONG_LONG", "np.uint64")
-            arrtypes[vtk.VTK_CHAR]          = ("CHAR",           "np.int8")
-            arrtypes[vtk.VTK_SHORT]         = ("SHORT",          "np.int16")
-            arrtypes[vtk.VTK_INT]           = ("INT",            "np.int32")
-            arrtypes[vtk.VTK_LONG]          = ("LONG",           "") # ??
-            arrtypes[vtk.VTK_LONG_LONG]     = ("LONG_LONG",      "np.int64")
-            arrtypes[vtk.VTK_FLOAT]         = ("FLOAT",          "np.float32")
-            arrtypes[vtk.VTK_DOUBLE]        = ("DOUBLE",         "np.float64")
-            arrtypes[vtk.VTK_SIGNED_CHAR]   = ("SIGNED_CHAR",    "np.int8")
-            arrtypes[vtk.VTK_ID_TYPE]       = ("ID",             "np.int64")
-
-            if ptdata.GetScalars():
-                vedo.printc("active array".ljust(14)+": ", c=c, bold=True, end="")
-                vedo.printc(ptdata.GetScalars().GetName(), "(pointdata)  ", c=c, bold=False)
-
-            if cldata.GetScalars():
-                vedo.printc("active array".ljust(14)+": ", c=c, bold=True, end="")
-                vedo.printc(cldata.GetScalars().GetName(), "(celldata)", c=c, bold=False)
 
             for i in range(ptdata.GetNumberOfArrays()):
                 name = ptdata.GetArrayName(i)
                 if name and ptdata.GetArray(i):
                     vedo.printc("pointdata".ljust(14) + ": ", c=c, bold=True, end="")
                     try:
-                        tt, nptt = arrtypes[ptdata.GetArray(i).GetDataType()]
+                        tt, _ = array_types[ptdata.GetArray(i).GetDataType()]
                     except:
                         tt = "VTKTYPE" + str(ptdata.GetArray(i).GetDataType())
-                        nptt = ""
                     ncomp = ptdata.GetArray(i).GetNumberOfComponents()
                     rng = ptdata.GetArray(i).GetRange()
                     vedo.printc(f'"{name}" ({ncomp} {tt}),', c=c, bold=False, end="")
@@ -1457,12 +1460,25 @@ def print_info(obj):
                         bold=False,
                     )
 
+            if ptdata.GetScalars():
+                vedo.printc("active scalars".ljust(14) + ": ", c=c, bold=True, end="")
+                vedo.printc(ptdata.GetScalars().GetName(), "(pointdata)  ", c=c, bold=False)
+
+            if ptdata.GetVectors():
+                vedo.printc("active vectors".ljust(14) + ": ", c=c, bold=True, end="")
+                vedo.printc(ptdata.GetVectors().GetName(), "(pointdata)  ", c=c, bold=False)
+
+            if ptdata.GetTensors():
+                vedo.printc("active tensors".ljust(14) + ": ", c=c, bold=True, end="")
+                vedo.printc(ptdata.GetTensors().GetName(), "(pointdata)  ", c=c, bold=False)
+
+            # same for cells
             for i in range(cldata.GetNumberOfArrays()):
                 name = cldata.GetArrayName(i)
                 if name and cldata.GetArray(i):
                     vedo.printc("celldata".ljust(14) + ": ", c=c, bold=True, end="")
                     try:
-                        tt, nptt = arrtypes[cldata.GetArray(i).GetDataType()]
+                        tt, _ = array_types[cldata.GetArray(i).GetDataType()]
                     except:
                         tt = cldata.GetArray(i).GetDataType()
                     ncomp = cldata.GetArray(i).GetNumberOfComponents()
@@ -1474,6 +1490,14 @@ def print_info(obj):
                         bold=False,
                     )
 
+            if cldata.GetScalars():
+                vedo.printc("active scalars".ljust(14) + ": ", c=c, bold=True, end="")
+                vedo.printc(cldata.GetScalars().GetName(), "(celldata)", c=c, bold=False)
+
+            if cldata.GetVectors():
+                vedo.printc("active vectors".ljust(14) + ": ", c=c, bold=True, end="")
+                vedo.printc(cldata.GetVectors().GetName(), "(celldata)", c=c, bold=False)
+
             for i in range(fldata.GetNumberOfArrays()):
                 name = fldata.GetArrayName(i)
                 if name and fldata.GetAbstractArray(i):
@@ -1505,14 +1529,13 @@ def print_info(obj):
         col = precision(pro.GetColor(), 3)
         alpha = pro.GetOpacity()
         npt = poly.GetNumberOfPoints()
-        ncl = poly.GetNumberOfCells()
         npl = poly.GetNumberOfPolys()
         nln = poly.GetNumberOfLines()
 
         vedo.printc("Mesh/Points".ljust(70), c="g", bold=True, invert=True, dim=1, end="")
 
         if hasattr(actor, "info") and "legend" in actor.info.keys() and actor.info["legend"]:
-            vedo.printc("legend".ljust(14)+": ", c="g", bold=True, end="")
+            vedo.printc("legend".ljust(14) + ": ", c="g", bold=True, end="")
             vedo.printc(actor.info["legend"], c="g", bold=False)
         else:
             print()
@@ -1537,6 +1560,7 @@ def print_info(obj):
                 vedo.printc(f"{cname}, rgb={precision(bcol,3)}", c="g", bold=False)
 
         vedo.printc("points".ljust(14) + ":", npt, c="g", bold=True)
+        # ncl = poly.GetNumberOfCells()
         # vedo.printc("cells".ljust(14)+":", ncl, c="g", bold=True)
         vedo.printc("polygons".ljust(14) + ":", npl, c="g", bold=True)
         if nln:
@@ -1566,7 +1590,7 @@ def print_info(obj):
         bz1, bz2 = precision(bnds[4], 3), precision(bnds[5], 3)
         vedo.printc(" z=(" + bz1 + ", " + bz2 + ")", c="g", bold=False)
 
-        _print_data(poly, mapper, "g")
+        _print_data(poly, "g")
 
         if hasattr(actor, "picked3d") and actor.picked3d is not None:
             idpt = actor.closest_point(actor.picked3d, return_point_id=True)
@@ -1583,7 +1607,6 @@ def print_info(obj):
         return
 
     if isinstance(obj, np.ndarray):
-        obj = obj
         cf = "y"
         vedo.printc("Numpy Array".ljust(70), c=cf, invert=True)
         vedo.printc(obj, c=cf)
@@ -1649,22 +1672,22 @@ def print_info(obj):
         vedo.printc(" y=(" + by1 + ", " + by2 + ")", c=cf, bold=False, end="")
         bz1, bz2 = precision(bnds[4], 3), precision(bnds[5], 3)
         vedo.printc(" z=(" + bz1 + ", " + bz2 + ")", c=cf, bold=False)
-        _print_data(ug, obj._mapper, cf)
+        _print_data(ug, cf)
 
     elif isinstance(obj, (vedo.volume.Volume, vedo.volume.VolumeSlice)):
         vedo.printc("Volume".ljust(70), c="b", bold=True, invert=True)
 
         img = obj.GetMapper().GetInput()
         vedo.printc("origin".ljust(14) + ": ", c="b", bold=True, end="")
-        vedo.printc(precision(obj.origin(),6), c="b", bold=False)
+        vedo.printc(precision(obj.origin(), 6), c="b", bold=False)
 
         vedo.printc("center".ljust(14) + ": ", c="b", bold=True, end="")
-        vedo.printc(precision(obj.center(),6), c="b", bold=False)
+        vedo.printc(precision(obj.center(), 6), c="b", bold=False)
 
         vedo.printc("dimensions".ljust(14) + ": ", c="b", bold=True, end="")
         vedo.printc(img.GetDimensions(), c="b", bold=False)
         vedo.printc("spacing".ljust(14) + ": ", c="b", bold=True, end="")
-        vedo.printc(precision(img.GetSpacing(),6), c="b", bold=False)
+        vedo.printc(precision(img.GetSpacing(), 6), c="b", bold=False)
         # vedo.printc("data dimension".ljust(14) + ": ", c="b", bold=True, end="")
         # vedo.printc(img.GetDataDimension(), c="b", bold=False)
 
@@ -1686,8 +1709,7 @@ def print_info(obj):
         vedo.printc("scalar range".ljust(14) + ": ", c="b", bold=True, end="")
         vedo.printc(img.GetScalarRange(), c="b", bold=False)
 
-        print_histogram(obj, horizontal=True, spacer=" "*10,
-            logscale=True, bins=8, height=15, c="b", bold=True)
+        print_histogram(obj, horizontal=True, logscale=True, bins=8, height=15, c="b", bold=True)
 
     elif isinstance(obj, vedo.Plotter) and obj.interactor:  # dumps Plotter info
         axtype = {
@@ -1737,9 +1759,7 @@ def print_info(obj):
             bold=False,
             c="c",
         )
-        vedo.printc(
-            "nr. of actors".ljust(14) + ":", len(obj.actors), bold=False, c="c", end=""
-        )
+        vedo.printc("nr. of actors".ljust(14) + ":", len(obj.actors), bold=False, c="c", end="")
         vedo.printc(" (" + str(totpt), "vertices)", bold=False, c="c")
         max_bns = np.max(bns, axis=0)
         min_bns = np.min(bns, axis=0)
@@ -1753,13 +1773,7 @@ def print_info(obj):
         if isinstance(obj.axes, dict):
             obj.axes = 1
         if obj.axes:
-            vedo.printc(
-                "axes style".ljust(14) + ":",
-                obj.axes,
-                axtype[obj.axes],
-                bold=False,
-                c="c",
-            )
+            vedo.printc("axes style".ljust(14) + ":", obj.axes, axtype[obj.axes], bold=False, c="c")
 
     elif isinstance(obj, vedo.Picture):  # dumps Picture info
         vedo.printc("Picture".ljust(70), c="y", bold=True, invert=True)
@@ -1824,7 +1838,7 @@ def print_histogram(
 ):
     """
     Ascii histogram printing.
-    
+
     Input can be a `vedo.Volume` or `vedo.Mesh`.
     Returns the raw data before binning (useful when passing vtk objects).
 
@@ -1954,23 +1968,27 @@ def print_histogram(
         vedo.printc(_v(), c=c, bold=bold)
     return data
 
-def print_table(*columns, headers=None, c='g'):
+
+def print_table(*columns, headers=None, c="g"):
     """
     Print lists as tables.
 
     Example:
-    ```python
-    list1 = [1, np.sqrt(2), 3]
-    list2 = ["A", "B", "C"]
-    list3 = [True, False, True]
-    headers = ["First Column", "Second Column", "Third Column"]
-    print_table(list1, list2, list3, headers=headers)
-    ```
+        ```python
+        from vedo.utils import print_table
+        list1 = ["A", "B", "C"]
+        list2 = [142, 220, 330]
+        list3 = [True, False, True]
+        headers = ["First Column", "Second Column", "Third Column"]
+        print_table(list1, list2, list3, headers=headers)
+        ```
+
+        ![](https://vedo.embl.es/images/feats/)
     """
     # If headers is not provided, use default header names
-    corner='─'
+    corner = "─"
     if headers is None:
-        headers = [f"Column {i}" for i in range(1, len(columns)+1)]
+        headers = [f"Column {i}" for i in range(1, len(columns) + 1)]
     assert len(headers) == len(columns)
 
     # Find the maximum length of the elements in each column and header
@@ -1978,11 +1996,15 @@ def print_table(*columns, headers=None, c='g'):
     max_len_headers = [max(len(str(header)), max_len) for header, max_len in zip(headers, max_lens)]
 
     # Construct the table header
-    header = "│ " + " │ ".join(header.ljust(max_len) for header, max_len in zip(headers, max_len_headers)) + " │"
+    header = (
+        "│ "
+        + " │ ".join(header.ljust(max_len) for header, max_len in zip(headers, max_len_headers))
+        + " │"
+    )
 
     # Construct the line separator
-    line1 = "┌" + corner.join("─"*(max_len+2) for max_len in max_len_headers) + "┐"
-    line2 = "└" + corner.join("─"*(max_len+2) for max_len in max_len_headers) + "┘"
+    line1 = "┌" + corner.join("─" * (max_len + 2) for max_len in max_len_headers) + "┐"
+    line2 = "└" + corner.join("─" * (max_len + 2) for max_len in max_len_headers) + "┘"
 
     # Print the table header
     vedo.printc(line1, c=c)
@@ -1991,7 +2013,11 @@ def print_table(*columns, headers=None, c='g'):
 
     # Print the data rows
     for row in zip(*columns):
-        row = "│ " + " │ ".join(str(col).ljust(max_len) for col, max_len in zip(row, max_len_headers)) + " │"
+        row = (
+            "│ "
+            + " │ ".join(str(col).ljust(max_len) for col, max_len in zip(row, max_len_headers))
+            + " │"
+        )
         vedo.printc(row, bold=False, c=c)
 
     # Print the line separator again to close the table
@@ -2095,9 +2121,7 @@ def camera_from_neuroglancer(state, zoom=300):
     return camera_from_quaternion(pos_nm, orient, pzoom * zoom, ngl_correct=True)
 
 
-def oriented_camera(
-    center=(0, 0, 0), up_vector=(0, 1, 0), backoff_vector=(0, 0, 1), backoff=1
-):
+def oriented_camera(center=(0, 0, 0), up_vector=(0, 1, 0), backoff_vector=(0, 0, 1), backoff=1.0):
     """
     Generate a `vtkCamera` pointed at a specific location,
     oriented with a given up direction, set to a backoff.
@@ -2130,7 +2154,7 @@ def camera_from_dict(camera, modify_inplace=None):
     cm_parallel_scale = camera.pop("parallel_scale", camera.pop("parallelScale", None))
     cm_thickness = camera.pop("thickness", None)
     cm_view_angle = camera.pop("view_angle", camera.pop("viewAngle", None))
-    if len(camera.keys()):
+    if len(camera.keys()) > 0:
         vedo.logger.warning(f"in camera_from_dict, key(s) not recognized: {camera.keys()}")
     if cm_pos is not None:            vcam.SetPosition(cm_pos)
     if cm_focal_point is not None:    vcam.SetFocalPoint(cm_focal_point)
@@ -2422,7 +2446,7 @@ def trimesh2vedo(inputobj):
         trim_cc, trim_al = "black", 1
         if hasattr(inputobj, "vertices_color"):
             trim_c = inputobj.vertices_color
-            if len(trim_c):
+            if len(trim_c) > 0:
                 trim_cc = trim_c[:, [0, 1, 2]] / 255
                 trim_al = trim_c[:, 3] / 255
                 trim_al = np.sum(trim_al) / len(trim_al)  # just the average
@@ -2520,7 +2544,7 @@ def meshlab2vedo(mmesh):
         mmesh = mmesh.current_mesh()
 
     mpoints, mcells = mmesh.vertex_matrix(), mmesh.face_matrix()
-    if len(mcells):
+    if len(mcells) > 0:
         polydata = buildPolyData(mpoints, mcells)
     else:
         polydata = buildPolyData(mpoints, None)
@@ -2544,21 +2568,23 @@ def meshlab2vedo(mmesh):
             polydata.GetCellData().SetActiveScalars("MeshLabScalars")
 
     pnorms = mmesh.vertex_normal_matrix()
-    if len(pnorms):
+    if len(pnorms) > 0:
         polydata.GetPointData().SetNormals(numpy2vtk(pnorms))
 
     cnorms = mmesh.face_normal_matrix()
-    if len(cnorms):
+    if len(cnorms) > 0:
         polydata.GetCellData().SetNormals(numpy2vtk(cnorms))
     return polydata
 
+
 def open3d2vedo(o3d_mesh):
     """Convert `open3d.geometry.TriangleMesh` to a `vedo.Mesh`."""
     m = vedo.Mesh([np.array(o3d_mesh.vertices), np.array(o3d_mesh.triangles)])
-    # TODO: could also check whether normals and color are present in 
+    # TODO: could also check whether normals and color are present in
     # order to port with the above vertices/faces
     return m
 
+
 def vedo2open3d(vedo_mesh):
     """
     Return an `open3d.geometry.TriangleMesh` version of the current mesh.
@@ -2579,6 +2605,7 @@ def vedo2open3d(vedo_mesh):
     # o3d_mesh.vertex_normals= o3d.utility.Vector3dVector(vedo_mesh.pointdata["Normals"])
     return o3d_mesh
 
+
 def vtk_version_at_least(major, minor=0, build=0):
     """
     Check the installed VTK version.
