@@ -24,11 +24,7 @@ Work with volumetric datasets (voxel data).
 ![](https://vedo.embl.es/images/volumetric/slicePlane2.png)
 """
 
-__all__ = [
-    "BaseVolume",  # included to generate documentation in pydoc
-    "Volume",
-    "VolumeSlice",
-]
+__all__ = ["BaseVolume", "Volume", "VolumeSlice"]
 
 
 ##########################################################################
@@ -36,17 +32,19 @@ class BaseVolume:
     """
     Base class. Do not instantiate.
     """
+
     def __init__(self):
         """Base class. Do not instantiate."""
 
         self._data = None
         self._mapper = None
         self.transform = None
+        self.pipeline = None
 
     def _repr_html_(self):
         """
         HTML representation of the Volume object for Jupyter Notebooks.
-        
+
         Returns:
             HTML text with the image and some properties.
         """
@@ -69,7 +67,7 @@ class BaseVolume:
         # statisitics
         bounds = "<br/>".join(
             [
-                utils.precision(min_x,4) + " ... " + utils.precision(max_x,4)
+                utils.precision(min_x, 4) + " ... " + utils.precision(max_x, 4)
                 for min_x, max_x in zip(self.bounds()[::2], self.bounds()[1::2])
             ]
         )
@@ -77,13 +75,13 @@ class BaseVolume:
         help_text = ""
         if self.name:
             help_text += f"<b> {self.name}: &nbsp&nbsp</b>"
-        help_text += '<b><a href="' + help_url + '" target="_blank">' + library_name + "</a></b>" 
+        help_text += '<b><a href="' + help_url + '" target="_blank">' + library_name + "</a></b>"
         if self.filename:
             dots = ""
             if len(self.filename) > 30:
                 dots = "..."
             help_text += f"<br/><code><i>({dots}{self.filename[-30:]})</i></code>"
-        
+
         pdata = ""
         if self._data.GetPointData().GetScalars():
             if self._data.GetPointData().GetScalars().GetName():
@@ -98,23 +96,32 @@ class BaseVolume:
 
         img = self.GetMapper().GetInput()
 
-        all = [
+        allt = [
             "<table>",
-            "<tr>", 
-            "<td>", image, "</td>",
-            "<td style='text-align: center; vertical-align: center;'><br/>", help_text,
+            "<tr>",
+            "<td>",
+            image,
+            "</td>",
+            "<td style='text-align: center; vertical-align: center;'><br/>",
+            help_text,
             "<table>",
             "<tr><td><b> bounds </b> <br/> (x/y/z) </td><td>" + str(bounds) + "</td></tr>",
             "<tr><td><b> dimensions </b></td><td>" + str(img.GetDimensions()) + "</td></tr>",
-            "<tr><td><b> voxel spacing </b></td><td>" + utils.precision(img.GetSpacing(),3) + "</td></tr>",
-            "<tr><td><b> in memory size </b></td><td>" + str(int(img.GetActualMemorySize() / 1024)) + "MB</td></tr>",
+            "<tr><td><b> voxel spacing </b></td><td>"
+            + utils.precision(img.GetSpacing(), 3)
+            + "</td></tr>",
+            "<tr><td><b> in memory size </b></td><td>"
+            + str(int(img.GetActualMemorySize() / 1024))
+            + "MB</td></tr>",
             pdata,
             cdata,
-            "<tr><td><b> scalar range </b></td><td>" + utils.precision(img.GetScalarRange(), 4) + "</td></tr>",
+            "<tr><td><b> scalar range </b></td><td>"
+            + utils.precision(img.GetScalarRange(), 4)
+            + "</td></tr>",
             "</table>",
             "</table>",
         ]
-        return "\n".join(all)
+        return "\n".join(allt)
 
     def _update(self, img):
         self._data = img
@@ -138,8 +145,7 @@ class BaseVolume:
         newvol.SetScale(self.GetScale())
         newvol.SetOrientation(self.GetOrientation())
         newvol.SetPosition(self.GetPosition())
-        newvol.pipeline = utils.OperationNode(
-            "clone", parents=[self], c="#bbd0ff", shape="diamond")
+        newvol.pipeline = utils.OperationNode("clone", parents=[self], c="#bbd0ff", shape="diamond")
         return newvol
 
     def imagedata(self):
@@ -227,7 +233,8 @@ class BaseVolume:
         imp.Update()
         self._update(imp.GetOutput())
         self.pipeline = utils.OperationNode(
-            f"permute_axes\n{tuple(x,y,z)}", parents=[self], c="#4cc9f0")
+            f"permute_axes\n{(x,y,z)}", parents=[self], c="#4cc9f0"
+        )
         return self
 
     def resample(self, new_spacing, interpolation=1):
@@ -254,7 +261,8 @@ class BaseVolume:
         rsp.Update()
         self._update(rsp.GetOutput())
         self.pipeline = utils.OperationNode(
-            f"resample\n{tuple(new_spacing)}", parents=[self], c="#4cc9f0")
+            f"resample\n{tuple(new_spacing)}", parents=[self], c="#4cc9f0"
+        )
         return self
 
     def interpolation(self, itype):
@@ -311,13 +319,7 @@ class BaseVolume:
         self.pipeline = utils.OperationNode("threshold", parents=[self], c="#4cc9f0")
         return self
 
-    def crop(
-            self,
-            left=None, right=None,
-            back=None, front=None,
-            bottom=None, top=None,
-            VOI=()
-        ):
+    def crop(self, left=None, right=None, back=None, front=None, bottom=None, top=None, VOI=()):
         """
         Crop a `Volume` object.
 
@@ -359,8 +361,7 @@ class BaseVolume:
         self._update(extractVOI.GetOutput())
 
         self.pipeline = utils.OperationNode(
-            "crop", parents=[self], c="#4cc9f0",
-            comment=f"dims={tuple(self.dimensions())}",
+            "crop", parents=[self], c="#4cc9f0", comment=f"dims={tuple(self.dimensions())}"
         )
         return self
 
@@ -409,13 +410,59 @@ class BaseVolume:
         ima.SetAppendAxis(axis)
         ima.Update()
         self._update(ima.GetOutput())
-        
+
         self.pipeline = utils.OperationNode(
-            "append", parents=[self, *volumes], c="#4cc9f0",
+            "append",
+            parents=[self, *volumes],
+            c="#4cc9f0",
             comment=f"dims={tuple(self.dimensions())}",
         )
         return self
 
+    def pad(self, voxels=10, value=0):
+        """
+        Add the specified number of voxels at the `Volume` borders.
+        Voxels can be a list formatted as `[nx0, nx1, ny0, ny1, nz0, nz1]`.
+
+        Arguments:
+            voxels : (int, list)
+                number of voxels to be added (or a list of length 4)
+            value : (int)
+                intensity value (gray-scale color) of the padding
+        
+        Example:
+            ```python
+            from vedo import Volume, dataurl, show
+            iso = Volume(dataurl+'embryo.tif').isosurface()
+            vol = iso.binarize(spacing=(100, 100, 100)).pad(10)
+            vol.dilate([15,15,15])
+            show(iso, vol.isosurface(), N=2, axes=1)
+            ```
+            ![](https://vedo.embl.es/images/volumetric/volume_pad.png)
+        """
+        x0, x1, y0, y1, z0, z1 = self._data.GetExtent()
+        pf = vtk.vtkImageConstantPad()
+        pf.SetInputData(self._data)
+        pf.SetConstant(value)
+        if utils.is_sequence(voxels):
+            pf.SetOutputWholeExtent(
+                x0 - voxels[0], x1 + voxels[1], 
+                y0 - voxels[2], y1 + voxels[3], 
+                z0 - voxels[4], z1 + voxels[5], 
+            )
+        else:
+            pf.SetOutputWholeExtent(
+                x0 - voxels, x1 + voxels, 
+                y0 - voxels, y1 + voxels, 
+                z0 - voxels, z1 + voxels,
+            )
+        pf.Update()
+        self._update(pf.GetOutput())
+        self.pipeline = utils.OperationNode(
+            "pad", comment=f"{voxels} voxels", parents=[self], c="#f28482"
+        )
+        return self
+
     def resize(self, *newdims):
         """Increase or reduce the number of voxels of a Volume with interpolation."""
         old_dims = np.array(self.imagedata().GetDimensions())
@@ -430,8 +477,7 @@ class BaseVolume:
         self._data.SetSpacing(new_spac)
         self._update(self._data)
         self.pipeline = utils.OperationNode(
-            "resize", parents=[self], c="#4cc9f0",
-            comment=f"dims={tuple(self.dimensions())}",
+            "resize", parents=[self], c="#4cc9f0", comment=f"dims={tuple(self.dimensions())}"
         )
         return self
 
@@ -506,15 +552,14 @@ class BaseVolume:
             mf = vtk.vtkImageLaplacian()
             mf.SetDimensionality(3)
             mf.SetInputData(image1)
-        
+
         if mf is not None:
             mf.Update()
             vol = Volume(mf.GetOutput())
             vol.pipeline = utils.OperationNode(
-                f"operation\n{op}", parents=[self], c="#4cc9f0",
-                shape="cylinder",
+                f"operation\n{op}", parents=[self], c="#4cc9f0", shape="cylinder"
             )
-            return vol ###########################
+            return vol  ###########################
 
         mat = vtk.vtkImageMathematics()
         mat.SetInput1Data(image1)
@@ -588,8 +633,7 @@ class BaseVolume:
         self._update(mat.GetOutput())
 
         self.pipeline = utils.OperationNode(
-            f"operation\n{op}", parents=[self, volume2],
-            shape="cylinder", c="#4cc9f0",
+            f"operation\n{op}", parents=[self, volume2], shape="cylinder", c="#4cc9f0"
         )
         return self
 
@@ -698,7 +742,7 @@ class BaseVolume:
 
         Examples:
             - [erode_dilate.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/erode_dilate.py)
-        
+
                 ![](https://vedo.embl.es/images/volumetric/erode_dilate.png)
         """
         ver = vtk.vtkImageContinuousErode3D()
@@ -714,6 +758,8 @@ class BaseVolume:
         Replace a voxel with the maximum over an ellipsoidal neighborhood of voxels.
         If `neighbours` of an axis is 1, no processing is done on that axis.
 
+        Check also `erode()` and `pad()`.
+
         Examples:
             - [erode_dilate.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/erode_dilate.py)
         """
@@ -767,7 +813,7 @@ class BaseVolume:
                 computed but set to this specified value instead.
 
         Examples:
-            - [euclidian_dist.py](examples/volumetric/euclidian_dist.py)
+            - [euclidian_dist.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/euclidian_dist.py)
         """
         euv = vtk.vtkImageEuclideanDistance()
         euv.SetInputData(self._data)
@@ -797,9 +843,7 @@ class BaseVolume:
         imc.Update()
         vol = Volume(imc.GetOutput())
 
-        vol.pipeline = utils.OperationNode(
-            "correlation_with", parents=[self, vol2], c="#4cc9f0",
-        )
+        vol.pipeline = utils.OperationNode("correlation_with", parents=[self, vol2], c="#4cc9f0")
         return vol
 
     def scale_voxels(self, scale=1):
@@ -810,7 +854,8 @@ class BaseVolume:
         rsl.Update()
         self._update(rsl.GetOutput())
         self.pipeline = utils.OperationNode(
-            f"scale_voxels\nscale={scale}", parents=[self], c="#4cc9f0")
+            f"scale_voxels\nscale={scale}", parents=[self], c="#4cc9f0"
+        )
         return self
 
 
@@ -820,6 +865,7 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
     Class to describe dataset that are defined on "voxels":
     the 3D equivalent of 2D pixels.
     """
+
     def __init__(
         self,
         inputobj=None,
@@ -904,7 +950,7 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
 
                 ![](https://vedo.embl.es/images/volumetric/read_volume2.png)
 
-        .. note:: 
+        .. note::
             if a `list` of values is used for `alphas` this is interpreted
             as a transfer function along the range of the scalar.
         """
@@ -912,12 +958,12 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
         BaseGrid.__init__(self)
         BaseVolume.__init__(self)
         # super().__init__()
-        
+
         ###################
         if isinstance(inputobj, str):
 
             if "https://" in inputobj:
-                inputobj = vedo.io.download(inputobj, verbose=False)  # fpath
+                inputobj = vedo.file_io.download(inputobj, verbose=False)  # fpath
             elif os.path.isfile(inputobj):
                 pass
             else:
@@ -979,9 +1025,9 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
 
                 img = vtk.vtkImageData()
                 if dims is not None:
-                    img.SetDimensions(dims[2],dims[1],dims[0])
+                    img.SetDimensions(dims[2], dims[1], dims[0])
                 else:
-                    if len(inputobj.shape)==1:
+                    if len(inputobj.shape) == 1:
                         vedo.logger.error("must set dimensions (dims keyword) in Volume")
                         raise RuntimeError()
                     img.SetDimensions(inputobj.shape)
@@ -1004,8 +1050,8 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
 
         elif isinstance(inputobj, str):
             if "https://" in inputobj:
-                inputobj = vedo.io.download(inputobj, verbose=False)
-            img = vedo.io.loadImageData(inputobj)
+                inputobj = vedo.file_io.download(inputobj, verbose=False)
+            img = vedo.file_io.loadImageData(inputobj)
 
         else:
             vedo.logger.error(f"cannot understand input type {inputtype}")
@@ -1036,13 +1082,12 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
         self._alpha = alpha
         self._alpha_grad = alpha_gradient
         self._alpha_unit = alpha_unit
-        
-        self.pipeline = utils.OperationNode("Volume",
-            comment=f"dims={tuple(self.dimensions())}", c="#4cc9f0",
+
+        self.pipeline = utils.OperationNode(
+            "Volume", comment=f"dims={tuple(self.dimensions())}", c="#4cc9f0"
         )
         #######################################################################
 
-
     def _update(self, data):
         self._data = data
         self._data.GetPointData().Modified()
@@ -1171,6 +1216,8 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
             vol.mask(data_mask)
             show(vol, axes=1).close()
         ```
+        See also:
+            `volume.hide_voxels()`
         """
         mask = Volume(data.astype(np.uint8))
         try:
@@ -1180,6 +1227,29 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
             vedo.logger.error("volume.mask() must create the volume with Volume(..., mapper='gpu')")
         return self
 
+    def hide_voxels(self, ids):
+        """
+        Hide voxels (cells) from visualization.
+
+        Example:
+            ```python
+            from vedo import *
+            embryo = Volume(dataurl+'embryo.tif')
+            embryo.hide_voxels(list(range(10000)))
+            show(embryo, axes=1).close()
+            ```
+
+        See also:
+            `volume.mask()`
+        """
+        ghost_mask = np.zeros(self.ncells, dtype=np.uint8)
+        ghost_mask[ids] = vtk.vtkDataSetAttributes.HIDDENCELL
+        name = vtk.vtkDataSetAttributes.GhostArrayName()
+        garr = utils.numpy2vtk(ghost_mask, name=name, dtype=np.uint8)
+        self._data.GetCellData().AddArray(garr)
+        self._data.GetCellData().Modified()
+        return self
+
     def alpha_gradient(self, alpha_grad, vmin=None, vmax=None):
         """
         Assign a set of tranparencies to a volume's gradient
@@ -1208,7 +1278,7 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
         gotf = volumeProperty.GetGradientOpacity()
         if utils.is_sequence(alpha_grad):
             alpha_grad = np.array(alpha_grad)
-            if len(alpha_grad.shape)==1: # user passing a flat list e.g. (0.0, 0.3, 0.9, 1)
+            if len(alpha_grad.shape) == 1:  # user passing a flat list e.g. (0.0, 0.3, 0.9, 1)
                 for i, al in enumerate(alpha_grad):
                     xalpha = vmin + (vmax - vmin) * i / (len(alpha_grad) - 1)
                     # Create transfer mapping scalar value to gradient opacity
@@ -1271,7 +1341,7 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
 
     @deprecated(reason=vedo.colors.red + "Please use slice_plane()" + vedo.colors.reset)
     def slicePlane(self, *a, **b):
-        "Deprecated. Please use `scalar_range()`"
+        "Deprecated. Please use `slice_plane()`"
         return self.slice_plane(*a, **b)
 
     def slice_plane(self, origin=(0, 0, 0), normal=(1, 1, 1), autocrop=False):
@@ -1279,7 +1349,7 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
         Extract the slice along a given plane position and normal.
 
         Example:
-            - [slicePlane1.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/slicePlane1.py)
+            - [slice_plane1.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/slice_plane1.py)
 
                 ![](https://vedo.embl.es/images/volumetric/slicePlane1.gif)
         """
@@ -1306,8 +1376,7 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
         msh = Mesh(vslice.GetOutput())
         msh.SetOrientation(T.GetOrientation())
         msh.SetPosition(pos)
-        msh.pipeline = utils.OperationNode(
-            "slice_plane", parents=[self], c="#4cc9f0:#e9c46a")
+        msh.pipeline = utils.OperationNode("slice_plane", parents=[self], c="#4cc9f0:#e9c46a")
         return msh
 
     def warp(self, source, target, sigma=1, mode="3d", fit=False):
@@ -1408,9 +1477,12 @@ class Volume(BaseVolume, BaseGrid, vtk.vtkVolume):
             bb.apply_transform(TI)
             bounds = bb.GetBounds()
             bounds = (
-                bounds[0]/spacing[0], bounds[1]/spacing[0],
-                bounds[2]/spacing[1], bounds[3]/spacing[1],
-                bounds[4]/spacing[2], bounds[5]/spacing[2],
+                bounds[0] / spacing[0],
+                bounds[1] / spacing[0],
+                bounds[2] / spacing[1],
+                bounds[3] / spacing[1],
+                bounds[4] / spacing[2],
+                bounds[5] / spacing[2],
             )
             bounds = np.round(bounds).astype(int)
             reslice.SetOutputExtent(bounds)
@@ -1428,6 +1500,7 @@ class VolumeSlice(BaseVolume, Base3DProp, vtk.vtkImageSlice):
     """
     Derived class of `vtkImageSlice`.
     """
+
     def __init__(self, inputobj=None):
         """
         This class is equivalent to `Volume` except for its representation.
@@ -1454,7 +1527,7 @@ class VolumeSlice(BaseVolume, Base3DProp, vtk.vtkImageSlice):
         ###################
         if isinstance(inputobj, str):
             if "https://" in inputobj:
-                inputobj = vedo.io.download(inputobj, verbose=False)  # fpath
+                inputobj = vedo.file_io.download(inputobj, verbose=False)  # fpath
             elif os.path.isfile(inputobj):
                 pass
             else:
@@ -1515,15 +1588,15 @@ class VolumeSlice(BaseVolume, Base3DProp, vtk.vtkImageSlice):
         elif "UniformGrid" in inputtype:
             img = inputobj
 
-        elif hasattr(inputobj, "GetOutput"): # passing vtk object, try extract imagdedata
+        elif hasattr(inputobj, "GetOutput"):  # passing vtk object, try extract imagdedata
             if hasattr(inputobj, "Update"):
                 inputobj.Update()
             img = inputobj.GetOutput()
 
         elif isinstance(inputobj, str):
             if "https://" in inputobj:
-                inputobj = vedo.io.download(inputobj, verbose=False)
-            img = vedo.io.loadImageData(inputobj)
+                inputobj = vedo.file_io.download(inputobj, verbose=False)
+            img = vedo.file_io.loadImageData(inputobj)
 
         else:
             vedo.logger.error(f"cannot understand input type {inputtype}")
@@ -1603,8 +1676,8 @@ class VolumeSlice(BaseVolume, Base3DProp, vtk.vtkImageSlice):
 
     def fill_background(self, value=True):
         """
-        Instead of rendering only to the image border, 
-        render out to the viewport boundary with the background color. 
+        Instead of rendering only to the image border,
+        render out to the viewport boundary with the background color.
         The background color will be the lowest color on the lookup
         table that is being used for the image."""
         self._mapper.SetBackground(value)
